#!/usr/bin/python3
# -*- coding: utf-8 -*-

### BEGIN LICENSE

# Copyright (C) 2013 National University of Defense Technology(NUDT) & Kylin Ltd

# Author:
#     maclin <majun@ubuntukylin.com>
#     Shine Huang<shenghuang@ubuntukylin.com>  
# Maintainer:
#     maclin <majun@ubuntukylin.com>

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

import urllib.request, urllib.error, urllib.parse
import json
import apt
from models.globals import Globals
from .application import Application
from utils.log_manager import LogManager

import gettext
gettext.textdomain("kylin-software-center")
_ = gettext.gettext
#This class is the abstraction of a 
class Category:

    #
    def __init__(self, category_name, display_name, index, visible, iconfile, apps):
        
        self.display_name = display_name
        self.category_name = category_name
        self.index = index
        self.iconfile = iconfile
        self.apps = apps
        self.visible = visible

    @property
    def name(self):
        return self.display_name

    # @property
    # def category_name(self):
    #     return self.category_name

    # @property
    # def apps(self):
    #     return self.apps

    # @property
    # def iconfile(self):
    #     return self.iconfile

    # @property
    # def index(self):
    #     return self.index

    # @property
    # def visible(self):
    #     return self.visible


    #get app by name
    #This function can ben optimized by map from pkgname to app
    def get_application_byname(self,pkgname):
        app = None
        try:
            app = self.apps[pkgname]
        except:
            app = None
        else:
            try:
                if app.package is None or app.package.candidate is None:
                    app = None
            except:
                app = None
        return app

    #
    # 函数：获取安装、升级、卸载应用个数
    #
    def get_application_count(self):
        inst = 0
        up = 0
        all = 0
        if(self.apps is not None):
            for (appname, app) in list(self.apps.items()):
                if app.package is None or app.package.candidate is None:
                    continue
                all = all + 1
                if app.is_installed:
                    inst = inst + 1
                if app.is_upgradable:
                    up = up + 1

        return (inst, up, all)


if __name__ == "__main__":

    cache = apt.Cache()
    cache.open()
    if (Globals.DEBUG_SWITCH):
        #print((len(cache)))
        LogManager.INFO(_(str(len(cache))))

    #cat1 = Category("devel","开发工具","",[])
    cat1 = Category("devel", _("Development tools"), "", [])
    if (Globals.DEBUG_SWITCH):
        print((cat1.name))
        print((cat1.apps))
        LogManager.INFO(_(str(cat1.name)))
        LogManager.INFO(_(str(cat1.apps)))
     




#!/usr/bin/python3
# -*- coding: utf-8 -*-


from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
from models.enums import setLongTextToElideFormat,BUTTON_PRESSED,BUTTON_LEAVE,BUTTON_ENTER,AppMsg,PKG_NAME
from models.application import *
from models.apkinfo import *
from utils import commontools
from ui.circular_progress_bar import *
from ui.uninstall_btn import *
from ui.shot_detail import *
# import time
import gettext
gettext.bindtextdomain("ubuntu-kylin-software-center", "/usr/share/locale")
gettext.textdomain("ubuntu-kylin-software-center")
_ = gettext.gettext


class Inside_Card_Widget(QFrame):
    is_remove = False
    clicked_card = pyqtSignal(Application)
    clicked_kycard = pyqtSignal(ApkInfo)
    send_download_progress = pyqtSignal(int)
    puase_download = pyqtSignal(Application)
    puase_apk_download = pyqtSignal(ApkInfo)
    check_action_btn_state = pyqtSignal(str)
    send_progress = pyqtSignal(int)
    init_detail_display = pyqtSignal()
    init_card_over = pyqtSignal(QWidget)
    check_all_check_statue = pyqtSignal()
    btn_text = ""

    def __init__(self, category,width,hight,app,is_remove_app,mw,detail,ca,parent=None):
        QFrame.__init__(self, parent)
        self.app = app
        self.mw = mw
        self.category = category
        self.x_width = width
        self.y_height = hight
        self.detail_widget = detail
        self.pre_progress = 0
        self.m_parent = parent
        self.narrow_btn_time = QTimer()
        self.is_remove_app = is_remove_app
        self.font = QFont()
        self.font.setPixelSize(14)
        self.m_font = QFontMetrics(self.font)
        self.ca = ca
        self.init_ui()
        self.init_card_over.connect(self.detail_widget.mw.slot_init_insidecard_over)
        self.clicked_card.connect(self.detail_widget.slot_clicked_card)
        self.clicked_kycard.connect(self.detail_widget.slot_clicked_card)
        self.mw.sigenal_show_downloading_widget.connect(self.show_downloading_widget)
        self.check_action_btn_state.connect(self.detail_widget.slot_check_action_btn_state)
        self.narrow_btn_time.timeout.connect(self.move_btn)
        self.init_detail_display.connect(self.slot_init_detail_widget)
        self.init_detail_display.emit()
        self.show()

    def init_ui(self):
        self.resize(self.x_width,self.y_height)
        # self.setAutoFillBackground(True)
        self.setFocusPolicy(Qt.NoFocus)
        self.setWindowFlags(Qt.FramelessWindowHint)
        if(Globals.THEME_COLOR == 0):
            self.setStyleSheet("QFrame{border-radius: 12px;}")
            palette1 = QPalette()
            palette1.setColor(self.backgroundRole(), QColor(247, 248, 249))  # 设置背景颜色
            self.setPalette(palette1)
            self.setAutoFillBackground(True)
        else:
            self.setStyleSheet("QFrame{border-radius: 12px;}")
            palette1 = QPalette()
            palette1.setColor(self.backgroundRole(), QColor(31, 32, 34))  # 设置背景颜色
            self.setPalette(palette1)
            self.setAutoFillBackground(True)
            # self.setStyleSheet("QFrame{background: #2B2B2C;border-radius: 12px;}")


    def slot_init_detail_widget(self):
        self.check_btn = QCheckBox(self)
        self.check_btn.resize(16,16)
        self.check_btn.setFocusPolicy(Qt.NoFocus)
        self.check_btn.setAttribute(Qt.WA_TranslucentBackground)
        self.check_btn.setCheckState(Qt.Unchecked)
        self.check_btn.setStyleSheet(
            "QCheckBox{border-radius: 8px;spacing: 0px;color:#666666;font-size:14px;background-color:rgba(0,0,0,0);border: 0px solid #8F9399;}" \
            "QCheckBox:hover{background-color:rgba(0,0,0,0);border-radius: 8px;image: url(./res/circular_uncheck.png);}" \
            "QCheckBox::indicator{width: 16px;height: 16px;border-radius:8px;}" \
            "QCheckBox::indicator:unchecked{background-color:rgba(0,0,0,0);border:0px solid #bfbfbf;image: url(./res/circular_uncheck.png);}" \
            "QCheckBox::indicator:unchecked:hover{background-color:rgba(0,0,0,0);border: 0px solid #8F9399;image: url(./res/circular_uncheck.png);}" \
            "QCheckBox::indicator:unchecked:pressed{background-color:rgba(0,0,0,0);border:0px solid #415FC4;image: url(./res/circular_uncheck.png);}" \
            "QCheckBox::indicator{width: 16px;height: 16px;}" \
            "QCheckBox::indicator:checked{border-radius: 8px;background-color: rgba(0,0,0,0);border:0px solid #415FC4;image: url(./res/circular_check.png);}" \
            "QCheckBox::indicator:checked:hover{border-radius: 8px;background-color:rgba(0,0,0,0);border:0px solid #415FC4;image: url(./res/circular_check.png);}" \
            "QCheckBox::indicator:checked:pressed{border-radius: 8px;background-color:rgba(0,0,0,0);border:0px solid #415FC4;image: url(./res/circular_check.png);}")
        self.check_btn.move(self.width()-self.check_btn.width()-20,20)
        self.check_btn.clicked.connect(lambda:self.mw.slot_clicked_check_btn(self))
        self.check_btn.hide()


        self.icon_label = QLabel(self)
        self.icon_label.resize(48,48)
        self.icon_label.move(20,20)
        iconpath = commontools.get_big_icon_path(self.app.pkgname)
        photo = Photo(iconpath, self.icon_label.width(),
                      self.icon_label.height(),
                      self.icon_label)
        photo.shot_photo_change(iconpath)
        # photo.resize_image()
        photo.show()
        self.icon_label.setStyleSheet("QLabel{border-radius: 8px;background-color:transparent;}")
        # self.icon_label.setStyleSheet("QLabel{border-radius: 8px;border-image: url('"+iconpath+"') 0 0 0 0 stretch strectch;background-color:transparent;}")
        #self.icon_label.setStyleSheet("QLabel{background-image:url('" + iconpath + "');background-color:transparent;background-position:center;background-repeat:no-repeat;}")

        self.name_label = QLabel(self)
        self.name_label.setAttribute(Qt.WA_TranslucentBackground)
        self.name_label.move(self.icon_label.x()+self.icon_label.width()+10,self.icon_label.y()+4)
        self.name_label.setFixedWidth(self.width()-self.name_label.x()-40)
        # self.name_label.setMaximumWidth(120)
        self.name_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #303133;line-height: 17px;}")
        if(Globals.LAN == "zh_CN"):
            if self.app.displayname_cn != '' and self.app.displayname_cn is not None and self.app.displayname_cn != 'None':
                setLongTextToElideFormat(self.name_label, self.app.displayname_cn)
                if("…" in self.name_label.text()):
                    self.name_label.setToolTip(self.app.displayname_cn)
            else:
                setLongTextToElideFormat(self.name_label, self.app.pkgname)
                if ("…" in self.name_label.text()):
                    self.name_label.setToolTip(self.app.pkgname)
        else:
            setLongTextToElideFormat(self.name_label, self.app.pkgname)
            if ("…" in self.name_label.text()):
                self.name_label.setToolTip(self.app.pkgname)
        self.name_label.adjustSize()
        self.category_label = QLabel(self)
        self.category_label.setAttribute(Qt.WA_TranslucentBackground)
        self.category_label.setAlignment(Qt.AlignLeft)
        self.category_label.setFixedHeight(24)
        self.category_label.setStyleSheet("QLabel{font-size: 12px;font-weight: 400;color: #8F9399;}")
        if (str(self.app.softStyle) == "3"):
            if (hasattr(self.mw.detailwidget,"kydroid_widget") and self.m_parent == self.mw.detailwidget.kydroid_widget.app_widget):
                if ( self.mw.detailwidget.kydroid_widget.type_name_label.text() not in self.app.category_name_cn and self.mw.detailwidget.kydroid_widget.type_name_label.text() not in self.app.category_name):
                    if self.app.category_name_cn != '' and self.app.category_name_cn is not None and self.app.category_name_cn != 'None' and Globals.LAN == "zh_CN":
                        self.category_label.setText(self.app.category_name_cn.split("、")[0])
                    else:
                        self.category_label.setText(self.app.category_name.split("、")[0])
                else:
                    self.category_label.setText(self.mw.detailwidget.kydroid_widget.type_name_label.text())
            else:
                if self.app.category_name_cn != '' and self.app.category_name_cn is not None and self.app.category_name_cn != 'None' and Globals.LAN == "zh_CN":
                    self.category_label.setText(self.app.category_name_cn.split("、")[0])
                else:
                    self.category_label.setText(self.app.category_name.split("、")[0])
        else:
            if (hasattr(self.mw.detailwidget,"category_widget") and self.m_parent == self.mw.detailwidget.category_widget.type_show_card_widget):
                if (self.mw.detailwidget.category_widget.type_name_label.text() not in self.app.category_name_cn and self.mw.detailwidget.category_widget.type_name_label.text() not in self.app.category_name):
                    if self.app.category_name_cn != '' and self.app.category_name_cn is not None and self.app.category_name_cn != 'None' and Globals.LAN == "zh_CN":
                        self.category_label.setText(self.app.category_name_cn.split("、")[0])
                    else:
                        self.category_label.setText(self.app.category_name.split("、")[0])
                else:
                    self.category_label.setText(self.mw.detailwidget.category_widget.type_name_label.text())
            else:
                if self.app.category_name_cn != '' and self.app.category_name_cn is not None and self.app.category_name_cn != 'None' and Globals.LAN == "zh_CN":
                    self.category_label.setText(self.app.category_name_cn.split("、")[0])
                else:
                    self.category_label.setText(self.app.category_name.split("、")[0])
        # else:
        #     # if(str(self.app.softStyle) == "2"):
        #     #     self.category_label.setText(self.app.manufacturers)
        #     # else:
        #     if self.app.category_name_cn != '' and self.app.category_name_cn is not None and self.app.category_name_cn != 'None' and Globals.LAN == "zh_CN":
        #         self.category_label.setText(self.app.category_name_cn.split("、")[0])
        #     else:
        #         self.category_label.setText(self.app.category_name.split("、")[0])
        self.category_label.adjustSize()
        self.category_label.move(self.name_label.x(),self.name_label.y()+self.name_label.height()+4)
        self.btn = QPushButton(self)
        self.btn.setFocusPolicy(Qt.NoFocus)
        self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #FFFFFF;line-height: 12px;border-radius: 12px;border: 0px solid #3790FA;background: #3790FA;}QPushButton:hover{background: #40A9FB;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
        # self.btn.resize(52,24)
        self.btn.move(self.width()-self.btn.width()-20,self.height()-self.btn.height()-20)
        self.btn.hide()
        self.btn.clicked.connect(lambda: self.mw.slot_click_action_btn(self, self.btn.text(), self.app))

        self.down_progress = Circular_Progress_Bar(22, 22, self.app.pkgname,self)
        self.down_progress.update_progress(self.app.percent)
        self.down_progress.move(self.width() - self.down_progress.width() - 20,
                                self.height() - self.down_progress.height() - 20)
        self.send_progress.connect(self.down_progress.GenUpdate)
        self.down_progress.hide()
        self.cancel_btn = QPushButton(self)
        self.cancel_btn.setFocusPolicy(Qt.NoFocus)
        self.cancel_btn.resize(22, 22)
        self.cancel_btn.setStyleSheet("QPushButton{background-image:url(./res/cancel1.png);border-radius:11px;}QPushButton:hover{background-image:url(./res/cancel1_hover.png);border-radius:11px;}")
        # self.cancel_btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #303133;line-height: 12px;text-align: center;background: rgba(55, 144, 250, 0.08);border-radius: 12px;}QPushButton:hover{background: #3790FA;border-radius: 12px;color: #FFFFFF;font-weight: 400;}QPushButton:pressed{background: #296CD9;color: #FFFFFF;font-weight: 500;}")
        # self.cancel_btn.setText(_("cancel"))
        self.cancel_btn.move(self.down_progress.x() - self.cancel_btn.width() - 8,
                             self.height() - self.cancel_btn.height() - 20)
        self.cancel_btn.hide()
        self.cancel_btn.clicked.connect(lambda: self.mw.slot_click_cancel_btn(self, self.app))
        self.remove_btn = uninstall_btn(self)
        self.remove_btn.move(self.width() - self.remove_btn.width() - 20, self.height() - self.remove_btn.height() - 20)
        self.remove_btn.hide()
        self.down_progress.btn.clicked.connect(self.slot_puase_download)
        self.down_progress.cont_btn.clicked.connect(lambda :self.mw.re_download_app(self.app))
        self.change_btn_state(self.app.pkgname,self.app.status)
        self.slot_set_dark_mode()
        self.init_card_over.emit(self)

    #
    #函数：修改界面大小后重新设置界面控件的大小和位置
    #
    def re_move(self):
        self.name_label.setFixedWidth(self.width() - self.name_label.x()-40)
        if (Globals.LAN == "zh_CN"):
            if self.app.displayname_cn != '' and self.app.displayname_cn is not None and self.app.displayname_cn != 'None':
                setLongTextToElideFormat(self.name_label, self.app.displayname_cn)
                if ("…" in self.name_label.text()):
                    self.name_label.setToolTip(self.app.displayname_cn)
                else:
                    self.name_label.setToolTip("")
            else:
                setLongTextToElideFormat(self.name_label, self.app.pkgname)
                if ("…" in self.name_label.text()):
                    self.name_label.setToolTip(self.app.pkgname)
        else:
            setLongTextToElideFormat(self.name_label, self.app.pkgname)
            if ("…" in self.name_label.text()):
                self.name_label.setToolTip(self.app.pkgname)
        self.btn.move(self.width()-self.btn.width()-20,self.height()-self.btn.height()-20)
        self.remove_btn.move(self.width() - self.remove_btn.width() - 20, self.height() - self.remove_btn.height() - 20)
        self.down_progress.move(self.width() - self.down_progress.width() - 20,
                                self.height() - self.down_progress.height() - 20)
        self.cancel_btn.move(self.down_progress.x() - self.cancel_btn.width() - 8,
                             self.height() - self.cancel_btn.height() - 20)
        self.check_btn.move(self.width() - self.check_btn.width() - 20, 20)

    #
    #函数：设置深色模式
    #
    def slot_set_dark_mode(self):
        if (Globals.THEME_COLOR == 0):
            # palette1 = QPalette()
            # palette1.setColor(self.backgroundRole(), QColor(247, 248, 249))  # 设置背景颜色
            # self.setPalette(palette1)
            # self.setAutoFillBackground(True)
            self.setStyleSheet("QFrame{border:0px solid #ff0000;border-radius: 12px;background-color:#F7F8F9;}")
            self.name_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #303133;line-height: 17px;}")
            self.category_label.setStyleSheet("QLabel{font-size: 12px;font-weight: 400;color: #8F9399;line-height: 17px;}")
            self.cancel_btn.setStyleSheet("QPushButton{background-image:url(./res/cancel1.png);border-radius:11px;}QPushButton:hover{background-image:url(./res/cancel1_hover.png);border-radius:11px;}")
        else:
            # painter = QPalette()
            # painter.setColor(QPalette.Background, QColor(46, 46, 46))
            # self.setPalette(painter)
            # self.setAutoFillBackground(True)
            self.setStyleSheet("QFrame{background: rgba(46, 46, 46, 0.88);border-radius: 12px;}")
            self.name_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #F9F9F9;line-height: 17px;}")
            self.category_label.setStyleSheet("QLabel{font-size: 12px;font-weight: 400;color: #8F9399;line-height: 17px;}")
            self.cancel_btn.setStyleSheet(
                "QPushButton{background-image:url(./res/cancel_dark.png);border-radius:11px;}QPushButton:hover{background-image:url(./res/cancel_hover_dark.png);border-radius:11px;}")
        if(self.btn.text() == _("uninstall")):
            self.set_btn_stylesheet(True)
        elif(self.btn.text() == _("uninstalled")):
            self.set_btn_stylesheet()
        self.down_progress.reflash_color()
        # self.show()
        # QApplication.processEvents()
        # time.sleep(0.1)


    #
    #函数：设置按钮的样式
    #
    def set_btn_stylesheet(self,is_uninstall = False):
        if(is_uninstall == True):
            self.btn.setEnabled(True)
            if(Globals.THEME_COLOR == 0):
                self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #3790FA;line-height: 12px;text-align: center;background: #EBEBEB;border-radius: 12px;}QPushButton:hover{border:0px;background: #3790FA;border-radius: 12px;color: #ffffff;font-weight: 400;}QPushButton:pressed{border:0px;background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;}")
            else:
                self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #3790FA;line-height: 12px;text-align: center;background: #454545;border-radius: 12px;}QPushButton:hover{border:0px;background: #3790FA;border-radius: 12px;color: #ffffff;font-weight: 400;}QPushButton:pressed{border:0px;background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;}")
        if(self.btn.text() == _("uninstalled")):
            self.check_btn.hide()
            self.check_btn.setChecked(False)
            self.check_btn.setEnabled(False)
            if (Globals.THEME_COLOR == 0):
                self.btn.setStyleSheet(
                    "QPushButton{font-size: 14px;font-weight: 400;color: #B3B3B3;line-height: 12px;background: #F5F5F5;border-radius: 12px;}")
            else:
                self.btn.setStyleSheet(
                    "QPushButton{font-size: 14px;font-weight: 400;color: #8F9399;line-height: 12px;background: rgba(245,245,245,0.19);border-radius: 12px;}")


    #
    # 函数：处理点击暂停
    #
    def slot_puase_download(self):
        if (type(self.app) != ApkInfo):
            self.puase_download.emit(self.app)
        else:
            self.puase_apk_download.emit(self.app)


    #
    # 函数：判断软件的desktop文件
    #
    def check_app_desktop(self, pkgname):
        # 对一些特殊软件单独处理

        fullcmd = ""

        desktopfile = "/usr/share/applications/" + pkgname + ".desktop"
        desktopfile1 = "/usr/share/applications/kde4/" + pkgname + ".desktop"

        if os.path.exists(desktopfile):
            return True
        elif os.path.exists(desktopfile1):
            return True
        else:
            if pkgname in Globals.PKG_NAME:
                pkgname = Globals.PKG_NAME[pkgname]

                desktopfile = "/usr/share/applications/" + pkgname + ".desktop"

                if os.path.exists(desktopfile):
                    return True
                else:
                    desktopfile = "/usr/share/applications/kde4/" + pkgname + ".desktop"
                    if (os.path.exists(desktopfile)):
                        return True
                    else:
                        return False
            else:
                return False


    #
    #函数：获取按钮的名字
    #
    def check_btn_text(self):
        self.btn.resize(52, 24)
        self.btn.move(self.width() - self.btn.width() - 20, self.height() - self.btn.height() - 20)
        self.remove_btn.stop_loading()
        self.remove_btn.hide()
        self.cancel_btn.hide()
        self.down_progress.hide()
        self.check_btn.setEnabled(True)
        self.btn.setEnabled(True)
        self.btn.show()
        if(self.app.status == PkgStates.REMOVING):
            self.slot_uninstall(self.app.pkgname,"uninstalling")
            return
        if (type(self.app) != ApkInfo):
            try:
                self.package = self.ca[self.app.pkgname]
            except:
                self.package = None
            if (self.package != None):
                if (self.package.is_installed == True and self.package.is_upgradable == True):
                    self.btn.setText(_("update"))
                    self.change_btn_width()
                    self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #3790FA;line-height: 12px;border-radius: 12px;background: rgba(55, 144, 250, 0.12);}QPushButton:hover{background: #3790FA;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
                elif (self.package.is_installed == False):
                    self.btn.setText(_("down"))
                    self.change_btn_width()
                    self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #FFFFFF;line-height: 12px;border-radius: 12px;border: 0px solid #3790FA;background: #3790FA;}QPushButton:hover{background: #40A9FB;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
                elif (self.package.is_installed == True and self.package.is_upgradable == False):
                    #self.btn.setText(_("run"))
                    if (self.app.pkgname == "kylin-installer"):
                        has_desktop = False
                    else:
                        has_desktop = self.check_app_desktop(self.app.pkgname)
                    if (has_desktop == True):
                        self.check_btn.hide()
                        self.check_btn.setChecked(False)
                        self.btn.setText(_("Open"))
                        self.change_btn_width()
                        self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #3790FA;line-height: 12px;border-radius: 12px;background: rgba(55, 144, 250, 0.12);}QPushButton:hover{background: #3790FA;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
                        # self.mw.check_btn_state()
                    else:
                        self.check_btn.hide()
                        self.check_btn.setChecked(False)
                        self.btn.setText(_("installed"))
                        self.change_btn_width()
                        self.btn.setEnabled(False)
                        self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #3790FA;line-height: 12px;background: rgba(55, 144, 250, 0.12);border-radius: 12px;}")
                        # self.mw.check_btn_state()
                    pass
            else:
                if(self.app.is_notice == False):
                    self.btn.setText(_("down"))
                    self.change_btn_width()
                else:
                    self.btn.setText(_("website"))
                    self.change_btn_width()
                self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #FFFFFF;line-height: 12px;border-radius: 12px;border: 0px solid #3790FA;background: #3790FA;}QPushButton:hover{background: #40A9FB;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
        else:
            if (self.app != None):
                # if ((self.mw.at.appmgr.apk_list == None or self.mw.at.appmgr.apk_list == [])):
                if(Globals.APK_EVNRUN == 0):
                    self.btn.setText(_("start env"))
                    self.change_btn_width()
                    self.btn.setStyleSheet(
                        "QPushButton{font-size: 14px;font-weight: 400;color: #3790FA;line-height: 12px;border-radius: 12px;background: rgba(55, 144, 250, 0.12);}QPushButton:hover{background: #3790FA;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
                else:
                    if (self.app.is_installed == True and self.app.is_upgradable == True):
                        self.btn.setText(_("update"))
                        self.change_btn_width()
                        self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #3790FA;line-height: 12px;border-radius: 12px;background: rgba(55, 144, 250, 0.12);}QPushButton:hover{background: #3790FA;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
                    elif (self.app.is_installed == False):
                        self.btn.setText(_("down"))
                        self.change_btn_width()
                        self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #FFFFFF;line-height: 12px;border-radius: 12px;border: 0px solid #3790FA;background: #3790FA;}QPushButton:hover{background: #40A9FB;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
                    elif (self.app.is_installed == True and self.app.is_upgradable == False):
                        self.check_btn.hide()
                        self.btn.setText(_("Open"))
                        self.change_btn_width()
                        self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #3790FA;line-height: 12px;border-radius: 12px;background: rgba(55, 144, 250, 0.12);}QPushButton:hover{background: #3790FA;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
                        pass
            else:
                self.btn.setText(_("down"))
                self.change_btn_width()
                self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #FFFFFF;line-height: 12px;border-radius: 12px;border: 0px solid #3790FA;background: #3790FA;}QPushButton:hover{background: #40A9FB;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
        self.set_btn_stylesheet()

    #
    #函数：重置按钮
    #
    def reload_btn(self,appname):
        if(appname == self.app.pkgname):
            if (self.app.is_removed == True):
                self.check_btn.hide()
                self.check_btn.setChecked(False)
                self.check_btn.setEnabled(False)
                self.slot_uninstall(appname, "uninstalled")
            else:
                if(self.is_remove_app):
                    self.btn.setText(_("uninstall"))
                    self.change_btn_width()
                    self.btn.show()
                    self.remove_btn.hide()
                    self.cancel_btn.hide()
                    self.down_progress.hide()
                    self.set_btn_stylesheet(True)
                else:
                    self.check_btn_text()

    #
    #函数：进度显示
    #
    def slot_get_download_progress(self,appname,progress):
        if(appname == self.app.pkgname):
            if(int(progress) == 100):
                if(self.is_remove == False):
                    self.narrow_btn_time.stop()
                    self.btn.resize(52, 24)
                    self.btn.move(self.width() - self.btn.width() - 20, self.height() - self.btn.height() - 20)
                    self.cancel_btn.hide()
                    self.down_progress.hide()
                    self.btn.setText(_("installing"))
                    self.change_btn_width()
                    self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #3790FA;line-height: 12px;background: rgba(55, 144, 250, 0.12);border-radius: 12px;}")
                    self.btn.show()
                    self.remove_btn.hide()
                else:
                    self.slot_uninstall(appname,"uninstalled")
            else:
                if(self.app.status == PkgStates.DOWNLOADING):
                    if(progress-self.pre_progress >=2):
                        self.app.percent = progress
                        self.send_progress.emit(progress)
                        self.pre_progress = progress
                    else:
                        self.send_progress.emit(self.pre_progress)


    #
    #函数：显示下载时卡片界面的显示
    #
    def show_downloading_widget(self, appname,is_cancel=False,is_puase = False):
        if(appname == self.app.pkgname):
            if (self.app.status != PkgStates.NOTHING):
                if (is_cancel == False):
                    if (is_puase == False):
                        if(self.app.status != PkgStates.INSTALLING):
                            self.btn.hide()
                            self.cancel_btn.show()
                            self.down_progress.show()
                            self.down_progress.btn.show()
                            self.down_progress.cont_btn.hide()
                            self.cancel_btn.move(self.down_progress.x() - self.cancel_btn.width() - 10,self.height() - self.cancel_btn.height() - 20)
                    else:
                        self.btn.setText(_("cont"))
                        self.change_btn_width()
                        self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #3790FA;line-height: 12px;border-radius: 12px;background: rgba(55, 144, 250, 0.12);}QPushButton:hover{background: #3790FA;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #3790FA;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
                        self.btn.show()
                        self.remove_btn.hide()
                        self.cancel_btn.show()
                        self.down_progress.hide()
                        self.cancel_btn.move(self.btn.x() - self.cancel_btn.width() - 10,self.height() - self.cancel_btn.height() - 20)
                else:
                    self.btn.resize(52, 24)
                    self.btn.move(self.width() - self.btn.width() - 20, self.height() - self.btn.height() - 20)
                    self.remove_btn.hide()
                    self.reload_btn(appname)
                    self.cancel_btn.hide()
                    self.down_progress.hide()
                    self.cancel_btn.move(self.down_progress.x() - self.cancel_btn.width() - 10,self.height() - self.cancel_btn.height() - 20)
                    self.btn.show()
                self.send_download_progress.emit(self.app.percent)
            else:
                self.check_btn_text()

    def slot_installed_over(self,appname):
        if (appname == self.app.pkgname):
            if(self.is_remove):
                self.check_btn.hide()
                self.check_btn.setChecked(False)
                self.check_btn.setEnabled(False)

    def change_btn_width(self):
        s = self.m_font.boundingRect(self.btn.text()).size().width()
        if (s+24 < 52):
            self.btn.setFixedSize(52,24)
        else:
            self.btn.setFixedSize(s+24,24)
        self.btn.move(self.width()-self.btn.width()-18,self.btn.y())

    def slot_uninstall(self,appname,state):
        if (appname == self.app.pkgname):
            self.btn.resize(52, 24)
            self.btn.move(self.width() - self.btn.width() - 20, self.height() - self.btn.height() - 20)
            self.cancel_btn.hide()
            self.down_progress.hide()
            if (state == "uninstalling"):
                self.is_remove = True
                self.check_btn.hide()
                self.check_btn.setEnabled(False)
                self.btn.setText(_("uninstalling"))
                self.change_btn_width()
                self.btn.hide()
                self.remove_btn.start_loading()
                self.remove_btn.show()
            else:
                if(self.m_parent == self.mw.detailwidget.mywidget.app_widget):
                    self.check_btn.hide()
                    self.check_btn.setChecked(False)
                    self.check_btn.setEnabled(False)
                    self.remove_btn.stop_loading()
                    self.remove_btn.hide()
                    self.btn.setText(_("uninstalled"))
                    self.change_btn_width()
                    if (Globals.THEME_COLOR == 0):
                        self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #B3B3B3;line-height: 12px;background: #F5F5F5;border-radius: 12px;}")
                    else:
                        self.btn.setStyleSheet(
                            "QPushButton{font-size: 14px;font-weight: 400;color: #8F9399;line-height: 12px;background: rgba(245,245,245,0.19);border-radius: 12px;}")
                    self.btn.setEnabled(False)
                    self.btn.show()
                    self.remove_btn.hide()
                    self.down_progress.hide()
                    self.check_action_btn_state.emit(appname)
                else:
                    self.is_remove = False
                    # self.app.is_removed = False
                    self.is_remove_app = False
                    # if(self.m_parent == self.mw.detailwidget.mywidget.history_widget.app_card_widget):
                    self.change_btn_state(appname,PkgStates.NOTHING)

    def change_kydroid_btn_statue(self):
        if(self.is_remove_app == False):
            if(type(self.app) == ApkInfo):
                for i in self.mw.at.appmgr.apk_list:
                    if(i.pkgname == self.app.pkgname):
                        self.app.is_installed = i.is_installed
                        self.app.is_upgradable = i.is_upgradable
                if(self.app.status == PkgStates.NOTHING):
                    self.check_btn_text()

    def change_btn_state(self,appname,state):
        if(appname == self.app.pkgname):
            if(state == PkgStates.NOTHING):
                if(self.app.is_removed == True and self.is_remove):
                    self.slot_uninstall(appname,"uninstalled")
                else:
                    if(self.is_remove_app == True):
                        self.btn.setText(_("uninstall"))
                        self.change_btn_width()
                        self.btn.show()
                        self.cancel_btn.hide()
                        self.remove_btn.hide()
                        self.down_progress.hide()
                        self.set_btn_stylesheet(True)
                    else:
                        self.check_btn_text()
                self.check_all_check_statue.emit()
            elif(state == PkgStates.REMOVED):
                self.app.status = PkgStates.NOTHING
                self.slot_uninstall(appname, "uninstalled")
            elif(state == PkgStates.INSTALLING):
                self.down_progress.hide()
                self.slot_get_download_progress(appname,100)
            elif(state == PkgStates.REMOVING):
                self.is_remove = True
                self.slot_uninstall(appname,"uninstalling")
            elif(state == PkgStates.INSTALLED):
                self.app.is_installed = True
                self.app.is_upgradable = False
                self.app.status = PkgStates.NOTHING
                self.reload_btn(appname)
                self.check_all_check_statue.emit()
            elif(state == PkgStates.DOWNLOADING):
                self.check_btn.setChecked(False)
                self.check_btn.hide()
                if (self.btn.isHidden() == False):
                    self.down_progress.init_down = True
                    self.down_progress.persent = 0
                    self.pre_progress = 0
                if (self.app.status != PkgStates.NOTHING):
                    if(self.btn.text() != ""):
                        self.narrow_btn_time.start(1)
                    else:
                        self.btn.hide()
                        self.cancel_btn.show()
                        self.down_progress.btn.show()
                        self.down_progress.cont_btn.hide()
                        self.down_progress.show()
            elif (state == PkgStates.PUASE):
                # self.show_downloading_widget(appname,False,True)
                self.app.status = PkgStates.PUASE
                self.btn.hide()
                self.cancel_btn.show()
                self.down_progress.show()
                self.down_progress.puase_download(self.app.percent)
                self.check_all_check_statue.emit()

    def move_btn(self):
        self.narrow_btn_time.stop()
        self.btn_text = self.btn.text()
        self.btn.setText("")
        w = self.btn.width()
        h = self.btn.height()
        x = self.btn.x()
        y = self.btn.y()
        if (self.app.status == PkgStates.DOWNLOADING):
            if(self.btn.width()>self.btn.height()):
                self.btn.hide()
                self.btn.setFixedSize(w-1,h)
                self.btn.move(x+1,y)
                self.btn.show()
                self.remove_btn.hide()
                self.down_progress.hide()
                self.narrow_btn_time.start(4)
            else:
                self.show_downloading_widget(self.app.pkgname)
                self.btn.setText(self.btn_text)
        else:
            self.btn.setText(self.btn_text)

    # 鼠标进入事件
    def enterEvent(self, event):
        self.status = BUTTON_ENTER
        self.setGeometry(self.x(), self.y(), self.width() , self.height())

        if (Globals.THEME_COLOR == 0):
            # painter = QPalette()
            # painter.setColor(QPalette.Background, QColor(55, 144, 250, 0.1))
            # self.setPalette(painter)
            # self.setAutoFillBackground(True)
            self.setStyleSheet("QFrame{border:0px solid #ff0000;border-radius: 12px;background: rgba(55,144,250,0.1);}")
        else:
            # painter = QPalette()
            # painter.setColor(QPalette.Background, QColor(255, 255, 255,0.1))
            # self.setPalette(painter)
            # self.setAutoFillBackground(True)
            self.setStyleSheet("QFrame{background: rgba(255,255,255,0.1);border-radius: 12px;}")
        if(self.check_btn.isEnabled() == True):
            if(self.check_btn.isChecked() == False and self.btn.text() != _("installing") and self.btn.text() != _("Open") and self.btn.text() != _("installed") and self.btn.text() != _("uninstalled") and self.cancel_btn.isHidden() and self.btn.text() != _("start env") and self.remove_btn.isHidden()):
                if(hasattr(self.detail_widget,"category_widget")):
                    if(self.m_parent == self.detail_widget.mywidget.app_widget or self.m_parent == self.detail_widget.mywidget.history_widget.app_card_widget or self.m_parent == self.detail_widget.category_widget.type_show_card_widget or (hasattr(self.detail_widget,"kydroid_widget") and self.m_parent == self.detail_widget.kydroid_widget.app_widget) or (hasattr(self.detail_widget,"drive_widget") and self.m_parent == self.detail_widget.drive_widget.type_show_card_widget)):
                        self.check_btn.setStyleSheet(
                            "QCheckBox{border-radius: 8px;spacing: 0px;color:#666666;font-size:14px;background-color:rgba(0,0,0,0);border: 0px solid #8F9399;background-image: url(./res/circular_uncheck.png);}" \
                            "QCheckBox:hover{background-color:rgba(0,0,0,0);border-radius: 8px;image: url(./res/circular_uncheck.png);}" \
                            "QCheckBox::indicator{width: 16px;height: 16px;border-radius:8px;}" \
                            "QCheckBox::indicator:unchecked{background-color:rgba(0,0,0,0);border:0px solid #bfbfbf;image: url(./res/circular_uncheck.png);}" \
                            "QCheckBox::indicator:unchecked:hover{background-color:rgba(0,0,0,0);border: 0px solid #8F9399;image: url(./res/circular_uncheck.png);}" \
                            "QCheckBox::indicator:unchecked:pressed{background-color:rgba(0,0,0,0);border:0px solid #415FC4;image: url(./res/circular_uncheck.png);}" \
                            "QCheckBox::indicator{width: 16px;height: 16px;}" \
                            "QCheckBox::indicator:checked{border-radius: 8px;background-color: rgba(0,0,0,0);border:0px solid #415FC4;image: url(./res/circular_check.png);}" \
                            "QCheckBox::indicator:checked:hover{border-radius: 8px;background-color:rgba(0,0,0,0);border:0px solid #415FC4;image: url(./res/circular_check.png);}" \
                            "QCheckBox::indicator:checked:pressed{border-radius: 8px;background-color:rgba(0,0,0,0);border:0px solid #415FC4;image: url(./res/circular_check.png);}")
                        self.check_btn.show()
                else:
                    if (self.m_parent == self.detail_widget.mywidget.app_widget or self.m_parent == self.detail_widget.mywidget.history_widget.app_card_widget or (hasattr(self.detail_widget,"kydroid_widget") and self.m_parent == self.detail_widget.kydroid_widget.app_widget) or (hasattr(self.detail_widget,"drive_widget") and self.m_parent == self.detail_widget.drive_widget.type_show_card_widget)):
                        self.check_btn.setStyleSheet(
                            "QCheckBox{border-radius: 8px;spacing: 0px;color:#666666;font-size:14px;background-color:rgba(0,0,0,0);border: 0px solid #8F9399;background-image: url(./res/circular_uncheck.png);}" \
                            "QCheckBox:hover{background-color:rgba(0,0,0,0);border-radius: 8px;image: url(./res/circular_uncheck.png);}" \
                            "QCheckBox::indicator{width: 16px;height: 16px;border-radius:8px;}" \
                            "QCheckBox::indicator:unchecked{background-color:rgba(0,0,0,0);border:0px solid #bfbfbf;image: url(./res/circular_uncheck.png);}" \
                            "QCheckBox::indicator:unchecked:hover{background-color:rgba(0,0,0,0);border: 0px solid #8F9399;image: url(./res/circular_uncheck.png);}" \
                            "QCheckBox::indicator:unchecked:pressed{background-color:rgba(0,0,0,0);border:0px solid #415FC4;image: url(./res/circular_uncheck.png);}" \
                            "QCheckBox::indicator{width: 16px;height: 16px;}" \
                            "QCheckBox::indicator:checked{border-radius: 8px;background-color: rgba(0,0,0,0);border:0px solid #415FC4;image: url(./res/circular_check.png);}" \
                            "QCheckBox::indicator:checked:hover{border-radius: 8px;background-color:rgba(0,0,0,0);border:0px solid #415FC4;image: url(./res/circular_check.png);}" \
                            "QCheckBox::indicator:checked:pressed{border-radius: 8px;background-color:rgba(0,0,0,0);border:0px solid #415FC4;image: url(./res/circular_check.png);}")
                        self.check_btn.show()


    #
    # 函数：鼠标离开事件
    #

    def leaveEvent(self, event):
        self.status = BUTTON_LEAVE
        self.resize(self.width() , self.height())
        if (Globals.THEME_COLOR == 0):
            # painter = QPalette()
            # painter.setColor(QPalette.Background, QColor(247, 248, 249))
            # self.setPalette(painter)
            # self.setAutoFillBackground(True)
            self.setStyleSheet("QFrame{border:0px solid #ff0000;border-radius: 12px;background: #F7F8F9;}")
        else:
            # painter = QPalette()
            # painter.setColor(QPalette.Background, QColor(46, 46, 46,0.88))
            # self.setPalette(painter)
            # self.setAutoFillBackground(True)
            self.setStyleSheet("QFrame{background:rgba(46, 46, 46, 0.88) ;border-radius: 12px;}")
        if(self.check_btn.isChecked() == False):
            if(hasattr(self.detail_widget,"category_widget")):
                if(self.m_parent == self.detail_widget.mywidget.app_widget or self.m_parent == self.detail_widget.mywidget.history_widget.app_card_widget or self.m_parent == self.detail_widget.category_widget.type_show_card_widget or (hasattr(self.detail_widget,"kydroid_widget") and self.m_parent == self.detail_widget.kydroid_widget.app_widget) or (hasattr(self.detail_widget,"drive_widget") and self.m_parent == self.detail_widget.drive_widget.type_show_card_widget)):
                    self.check_btn.hide()
            else:
                if (self.m_parent == self.detail_widget.mywidget.app_widget or self.m_parent == self.detail_widget.mywidget.history_widget.app_card_widget or (hasattr(self.detail_widget,"kydroid_widget") and self.m_parent == self.detail_widget.kydroid_widget.app_widget) or (hasattr(self.detail_widget,"drive_widget") and self.m_parent == self.detail_widget.drive_widget.type_show_card_widget)):
                    self.check_btn.hide()

    #
    # 函数：鼠标按下事件
    #
    def mousePressEvent(self, event):
        if event.button() == Qt.LeftButton:
            self.status = BUTTON_PRESSED
            if(type(self.app) == ApkInfo):
                self.clicked_kycard.emit(self.app)
            else:
                self.clicked_card.emit(self.app)
        else:
            event.ignore()



#!/usr/bin/python3
# -*- coding: utf-8 -*-


from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
import gettext
gettext.bindtextdomain("kylin-software-center", "/usr/share/locale")
gettext.textdomain("kylin-software-center")
_ = gettext.gettext

class Recommended_List_Widget(QWidget):
    cardcount = 0
    itemwidth = -1
    itemheight = -1
    space = 0
    card_width = 305
    card_height = 190
    def __init__(self,w,parent=None):
        QWidget.__init__(self, parent)
        self.w = w
        self.init_ui()


    def init_ui(self):
        self.resize(self.w, 450)
        self.setFocusPolicy(Qt.NoFocus)
        self.setWindowFlags(Qt.FramelessWindowHint)
        self.setAttribute(Qt.WA_TranslucentBackground)
        self.locale_lan = QLocale.system().name()
        self.titellabel = QLabel(self)
        self.titellabel.setAttribute(Qt.WA_TranslucentBackground)
        self.titellabel.setStyleSheet("QLabel{font-size: 24px;font-weight: 500;color: #303133;line-height: 33px;}")
        if self.locale_lan =="zh_CN":
            self.titellabel.setFixedHeight(26)
        else:
            self.titellabel.setFixedHeight(36)
        self.titellabel.setText(_("We play a lot. Are you sure you don't want to see it?"))
        # self.titellabel.adjustSize()
        self.titellabel.move(10, 0)

        self.card_widget = QWidget(self)
        self.card_widget.setAttribute(Qt.WA_TranslucentBackground)
        if self.locale_lan =="zh_CN":
            self.card_widget.move(0,self.titellabel.height()+20)
        else:
            self.card_widget.move(0,self.titellabel.height()+10)
        self.card_widget.resize(self.width(),self.height())

    #
    # 函数名:添加卡
    # Function:add card
    #
    def add_card(self, card):
        self.space = 16
        h_num = int((self.card_widget.width()-20) / (305))
        card_width = int(((self.card_widget.width()-20)-(h_num-1)*16)/h_num)
        card_height = int((card_width/305)*190)
        card.resize(card_width,card_height)
        card.re_move()
        # if(self.cardcount >=h_num*2):
        #     return
        v_num = int(self.cardcount/h_num)
        if(int(self.cardcount/h_num) == 0):
            if(self.cardcount%h_num == 0):
                x = 10
                y = 10
            else:
                x = int((card.width() + self.space)*(self.cardcount%h_num))+10
                y = 10
        else:
            if (self.cardcount % h_num == 0):
                x = 10
                y = 10+int(card.height())*(v_num)+20*v_num
            else:
                x = int((card.width() + self.space)*(self.cardcount%h_num))+10
                y = 10+int(card.height())*(v_num)+20*v_num
        card.move(x, y)
        self.cardcount = self.cardcount + 1
        # print("LLLLLLL",v_num)
        if(v_num < 2):
            self.card_widget.resize(self.width(), (card.height() + 20) * (v_num+1) + 20)
            self.resize(self.width(), (card.height() + 20) * (v_num+1) + 33+10)

    def reload_card(self):
        self.space = 16
        self.card_widget.resize(self.width(),self.height()-33)
        cards = self.card_widget.children()
        self.space = 16
        h_num = int((self.card_widget.width() - 20) / (305))
        get_card_width = int(((self.card_widget.width() - 20) - (h_num - 1) * 16) / h_num)
        get_card_height = int((get_card_width / 305) * 190)
        self.cardcount = 0
        for card in cards:
            v_num = int(self.cardcount / h_num)
            card.resize(get_card_width, get_card_height)
            card.re_move()
            if (int(self.cardcount / h_num) == 0):
                if (self.cardcount % h_num == 0):
                    x = 10
                    y = 10
                else:
                    x = int((card.width() + self.space) * (self.cardcount % h_num)) + 10
                    y = 10
            else:
                if (self.cardcount % h_num == 0):
                    x = 10
                    y = 10 + int(card.height()) * (v_num) + 20 * v_num
                else:
                    x = int((card.width() + self.space) * (self.cardcount % h_num)) + 10
                    y = 10 + int(card.height()) * (v_num) + 20 * v_num
            card.move(x, y)
            # if(card.isHidden()):
            #     card.show()
            self.cardcount = self.cardcount + 1
            if(v_num < 2):
                self.card_widget.resize(self.width(),(get_card_height+20)*(v_num+1)+20)
                self.resize(self.width(),(get_card_height+20)*(v_num+1)+33+10)
            



from Cryptodome.Cipher import AES
from Cryptodome import Random
from Cryptodome.Hash import SHA
from Cryptodome.Cipher import PKCS1_v1_5 as Cipher_pkcs1_v1_5
from Cryptodome.Signature import PKCS1_v1_5 as Signature_pkcs1_v1_5
from Cryptodome.PublicKey import RSA
import base64

class Aescrypt():
    def __init__(self,key=None,model=None,iv=None):
        if(key != None):
            self.key = self.add_16(key)
        else:
            self.key = key
        self.model = model
        self.iv = iv

    def add_16(self,par):
        if type(par) == str:
            par = par.encode()
        while len(par) % 16 != 0:
            par += b'\x00'
        return par

    def aesencrypt(self,text):
        text = self.add_16(text)
        if self.model == AES.MODE_CBC:
            self.aes = AES.new(self.key,self.model,self.iv)
        elif self.model == AES.MODE_ECB:
            self.aes = AES.new(self.key,self.model)
        self.encrypt_text = self.aes.encrypt(text)
        return self.encrypt_text

    def aesdecrypt(self,text):
        if self.model == AES.MODE_CBC:
            self.aes = AES.new(self.key,self.model,self.iv)
        elif self.model == AES.MODE_ECB:
            self.aes = AES.new(self.key,self.model)
        self.decrypt_text = self.aes.decrypt(text)
        self.decrypt_text = self.decrypt_text.strip(b"\x00")
        return self.decrypt_text

    #msg:byte 类型
    def add_key_encrypt(self,key,msg):
        rsakey = RSA.importKey(key)
        signer = Signature_pkcs1_v1_5.new(rsakey)
        digest = SHA.new()
        digest.update(msg)
        sign = signer.sign(digest)
        signature = base64.b64encode(sign)
        return signature

    #msg：为生产的加签了的数据，msg1为原始数据（均为byte类型）
    def add_key_dncrypt(self,key,msg,msg1):
        rsakey = RSA.importKey(key)
        verifier = Signature_pkcs1_v1_5.new(rsakey)
        digest = SHA.new()
        digest.update(msg1)
        is_verify = verifier.verify(digest, base64.b64decode(msg))
        return is_verify



#!/usr/bin/python3
# -*- coding: utf-8 -*-


from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
from ui.systembutton import *
from ui.systembutton import *
from ui.historical_installation_widget import *
import gettext
gettext.bindtextdomain("kylin-software-center", "/usr/share/locale")
gettext.textdomain("kylin-software-center")
_ = gettext.gettext

class Mine_Widget(QFrame):
    click_type_btn = pyqtSignal(str)
    card_width = 248
    card_height = 124
    card_space = 15
    def __init__(self,w,h, parent=None):
        QWidget.__init__(self, parent)
        self.w = w
        self.h = h
        self.m_parent = parent
        self.space = 50
        self.init_ui()

    def init_ui(self):
        self.resize(self.w,self.h)
        self.setAttribute(Qt.WA_TranslucentBackground)
        self.setStyleSheet("QFrame{border:0px;background-color:transparent;}")
        self.btn_widget = QWidget(self)
        self.btn_widget.setFixedSize(self.width()-self.space*2,114)
        self.btn_widget.move(int((self.width()-self.btn_widget.width())/2),0)

        self.downloading_btn = Click_Button(_("Onload"),self,self.btn_widget)
        self.downloading_btn.resize(80,24)
        self.downloading_btn.move(int((self.btn_widget.width()-self.downloading_btn.width()*4-12*3)/2),20)
        self.downloading_btn.show()

        self.update_btn = Click_Button(_("Updates"),self,self.btn_widget)
        self.update_btn.resize(80,24)
        self.update_btn.move(self.downloading_btn.x()+self.update_btn.width()+12,20)
        self.update_btn.show()

        self.update_tip_spot = QLabel(self.btn_widget)
        self.update_tip_spot.setFixedSize(6, 6)
        self.update_tip_spot.setStyleSheet("QLabel{background: #F56C6C;border-radius:3px;font-size: 12px;font-weight: 400;color: #FFFFFF;line-height: 16px;}")
        self.update_tip_spot.move(self.update_btn.x()+self.update_btn.width()-10,self.update_btn.y()-3)
        self.update_tip_spot.setAlignment(Qt.AlignCenter)
        self.update_tip_spot.hide()

        self.uninstall_btn = Click_Button(_("Uninstall"),self,self.btn_widget)
        self.uninstall_btn.resize(80, 24)
        self.uninstall_btn.move(self.update_btn.x()+self.update_btn.width()+12,20)
        self.uninstall_btn.show()

        self.installed_btn = Click_Button(_("Installation"),self,self.btn_widget)
        if(Globals.LAN == "zh_CN"):
            self.installed_btn.setFixedSize(self.uninstall_btn.width(), 24)
        else:
            self.installed_btn.setFixedSize(self.installed_btn.width(),24)
        self.installed_btn.move(self.uninstall_btn.x()+self.uninstall_btn.width()+12,20)
        self.installed_btn.show()

        self.downloading_num_label = QLabel(self.btn_widget)
        self.downloading_num_label.resize(18, 18)
        self.downloading_num_label.setMinimumWidth(18)
        self.downloading_num_label.setFixedHeight(18)
        self.downloading_num_label.setStyleSheet(
            "QLabel{background: #F56C6C;border-radius:9px;font-size: 12px;font-weight: 400;color: #FFFFFF;line-height: 16px;}")
        self.downloading_num_label.move(int((
                                                        self.btn_widget.width() - self.downloading_btn.width() * 4 - 12 * 3) / 2) + self.downloading_btn.width() - 10,
                                        13)
        self.downloading_num_label.setAlignment(Qt.AlignCenter)
        self.downloading_num_label.hide()

        self.update_num_label = QLabel(self.btn_widget)
        self.update_num_label.resize(18, 18)
        self.update_num_label.setMinimumWidth(18)
        self.update_num_label.setFixedHeight(18)
        self.update_num_label.setStyleSheet("QLabel{background: #F56C6C;border-radius:9px;font-size: 12px;font-weight: 400;color: #FFFFFF;line-height: 16px;}")
        self.update_num_label.move(self.downloading_btn.x()+self.downloading_btn.width()+12+self.update_btn.width()-10,13)
        self.update_num_label.setAlignment(Qt.AlignCenter)
        self.update_num_label.hide()

        self.type_name_label = QLabel(self.btn_widget)
        self.type_name_label.setAttribute(Qt.WA_TranslucentBackground)
        self.type_name_label.setStyleSheet("QLabel{font-size: 24px;font-weight: 600;color: #303133;line-height: 42px;}")
        self.type_name_label.move(0,self.installed_btn.y()+18)
        self.type_name_label.setText(_("Onload"))
        self.type_name_label.adjustSize()

        self.all_check = QPushButton(self.btn_widget)
        self.all_check.setFocusPolicy(Qt.NoFocus)
        self.all_check.setFixedSize(80,24)
        self.all_check.setStyleSheet("QPushButton{border:0px;font-size: 14px;font-weight: 500;color: #3790FA;line-height: 20px;border:0px solid #ff0000;}QPushButton:hover{background: rgba(55, 144, 250, 0.12);border-radius: 12px;}QPushButton:pressed{background: rgba(55, 144, 250, 0.12);border-radius: 12px;}")
        self.all_check.setText(_("all puase"))
        self.all_check.adjustSize()
        self.all_check.move(self.btn_widget.width()-self.all_check.width(),self.type_name_label.y() + self.type_name_label.height()+2-self.all_check.height())
        self.all_check.setEnabled(True)
        self.all_check.hide()

        self.download_all_check = QPushButton(self.btn_widget)
        self.download_all_check.setFocusPolicy(Qt.NoFocus)
        self.download_all_check.setFixedSize(80, 24)
        self.download_all_check.setStyleSheet("QPushButton{border:0px;font-size: 14px;font-weight: 500;color: #3790FA;line-height: 20px;border:0px solid #ff0000;}QPushButton:hover{background: rgba(55, 144, 250, 0.12);border-radius: 12px;}QPushButton:pressed{background: rgba(55, 144, 250, 0.12);border-radius: 12px;}")
        self.download_all_check.setText(_("all puase"))
        self.download_all_check.adjustSize()
        self.download_all_check.move(self.btn_widget.width() - self.download_all_check.width(),
                            self.type_name_label.y() + self.type_name_label.height() + 2 - self.download_all_check.height())
        self.download_all_check.setEnabled(True)
        self.download_all_check.hide()

        self.all_select_btn = QPushButton(self.btn_widget)
        self.all_select_btn.setFocusPolicy(Qt.NoFocus)
        self.all_select_btn.setFixedSize(80, 24)
        self.all_select_btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;line-height: 20px;background: transparent;border-radius: 13px;font-weight: 500;color: #606265;line-height: 20px;}QPushButton:hover{background: rgba(55, 144, 250, 0.12);color: #3790FA;border-radius: 12px;}PushButton:pressed{background: rgba(55, 144, 250, 0.12);color: #3790FA;border-radius: 12px;}")
        self.all_select_btn.setText(_("Select all"))
        self.all_select_btn.adjustSize()
        self.all_select_btn.move(self.all_check.x()-20-self.all_select_btn.width(),self.all_check.y())
        self.all_select_btn.hide()

        self.border = QLabel(self.btn_widget)
        self.border.setFixedSize(self.btn_widget.width(),1)
        self.border.move(0,self.type_name_label.y() + self.type_name_label.height() + 10)
        self.border.show()

        self.app_widget =  QWidget(self)
        self.app_widget.resize(self.width()-self.space*2,self.height()-self.btn_widget.height())
        self.app_widget.move(int((self.width()-self.app_widget.width())/2),int((self.height()-self.btn_widget.height()-self.app_widget.height())/2+self.btn_widget.height()))
        self.app_widget.setStyleSheet("QWidget{border-radius: 0px;}")
        self.app_widget.hide()

        self.scrollArea = QScrollArea(self)
        self.scrollArea.setWidget(self.app_widget)
        self.scrollArea.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
        self.scrollArea.horizontalScrollBar().setEnabled(False)
        self.scrollArea.setVerticalScrollBarPolicy(Qt.ScrollBarAsNeeded)
        self.scrollArea.setGeometry(int(self.btn_widget.x()+self.border.x()),int((self.height()-self.btn_widget.height()-self.app_widget.height())/2+self.btn_widget.height()),int(self.app_widget.width()+self.space-10),int(self.app_widget.height()-10))
        self.scrollArea.hide()
        self.scrollArea.verticalScrollBar().setStyleSheet("QScrollBar:vertical{margin:0px 0px 0px 0px;background-color:transparent;border:0px;width:6px;border-radius: 3px;}\
                     QScrollBar::handle:vertical{background-color:#C2C2C2;width:6px;border-radius:3px;} QScrollBar::handle:vertical:hover{background-color:#8F9399;opacity:0.1;width:6px;border-radius:3px;}  QScrollBar::handle:vertical:pressed{background-color:#8F9399;width:6px;border-radius:3px;}\
                     QScrollBar::sub-line:vertical{subcontrol-origin:margin;border:0px solid red;height:13px}\
                     QScrollBar::up-arrow:vertical{subcontrol-origin:margin;background-color:rgba(0,0,0,0);height:13px}\
                     QScrollBar::sub-page:vertical{background-color:transparent;}\
                     QScrollBar::add-page:vertical{background-color:transparent;}\
                     QScrollBar::down-arrow:vertical{background-color:rgba(0,0,0,0);}\
                     QScrollBar::add-line:vertical{subcontrol-origin:margin;border:0px solid green;height:13px}")

        self.downloading_widget = QWidget(self)
        self.downloading_widget.setAttribute(Qt.WA_TranslucentBackground)
        self.downloading_widget.resize(self.width()-self.space*2,self.height()-self.btn_widget.height())
        self.downloading_widget.move(int((self.width()-self.downloading_widget.width())/2),int((self.height()-self.btn_widget.height()-self.downloading_widget.height())/2+self.btn_widget.height()))
        self.downloading_widget.setStyleSheet("QWidget{border-radius: 0px;background-color:transparent;border:0px;}")
        self.downloading_widget.hide()

        self.text_prompt_label = QLabel(self)
        self.text_prompt_label.setAttribute(Qt.WA_TranslucentBackground)
        # self.text_prompt_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #BBBDCA;line-height: 24px;}")
        self.text_prompt_label.hide()

        self.no_app_tip_label = QLabel(self)
        self.no_app_tip_label.resize(240,240)
        if Globals.THEME_COLOR == 0:
            self.no_app_tip_label.setStyleSheet("QLabel{border-radius: 12px;background-image:url(./res/no_uninstall.png);}")
        else:
            self.no_app_tip_label.setStyleSheet("QLabel{border-radius: 12px;background-image:url(./res/no_uninstall_dark.png);}")
        self.no_app_tip_label.move(int((self.width()-self.no_app_tip_label.width())/2),int((self.height()-self.no_app_tip_label.height())/2))
        self.no_app_tip_label.hide()

        self.loadingmove = QMovie("./res/loadgif2.gif")
        self.loadingmove_dark = QMovie("./res/loadgifdark.gif")
        self.loadinglabel = QLabel(self)
        self.loadinglabel.resize( 350, 350)
        self.loadinglabel.move(int((self.width()-self.loadinglabel.width())/2),int((self.height()-self.loadinglabel.height())/2))
        self.loadinglabel.setAlignment(Qt.AlignCenter)
        if(Globals.THEME_COLOR == 0):
            self.loadinglabel.setMovie(self.loadingmove)
            self.loadingmove.start()
        else:
            self.loadinglabel.setMovie(self.loadingmove_dark)
            self.loadingmove_dark.start()

        self.loadinglabel.hide()
        #self.loadinglabel.show()

        self.scrollArea1 = QScrollArea(self)
        self.scrollArea1.setWidget(self.downloading_widget)
        self.scrollArea1.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
        self.scrollArea1.horizontalScrollBar().setEnabled(False)
        self.scrollArea1.setVerticalScrollBarPolicy(Qt.ScrollBarAsNeeded)
        self.scrollArea1.setGeometry(int(self.btn_widget.x()+self.border.x()),int((self.height()-self.btn_widget.height()-self.downloading_widget.height())/2+self.btn_widget.height()),int(self.downloading_widget.width()+self.space-10),int(self.downloading_widget.height()-10))
        self.scrollArea1.show()
        self.scrollArea1.verticalScrollBar().setStyleSheet("QScrollBar:vertical{margin:0px 0px 0px 0px;background-color:transparent;border:0px;width:6px;border-radius: 3px;}\
                     QScrollBar::handle:vertical{background-color:#C2C2C2;width:6px;border-radius:3px;} QScrollBar::handle:vertical:hover{background-color:#8F9399;opacity:0.1;width:6px;border-radius:3px;}  QScrollBar::handle:vertical:pressed{background-color:#8F9399;width:6px;border-radius:3px;}\
                     QScrollBar::sub-line:vertical{subcontrol-origin:margin;border:0px solid red;height:13px}\
                     QScrollBar::up-arrow:vertical{subcontrol-origin:margin;background-color:rgba(0,0,0,0);height:13px}\
                     QScrollBar::sub-page:vertical{background-color:transparent;}\
                     QScrollBar::add-page:vertical{background-color:transparent;}\
                     QScrollBar::down-arrow:vertical{background-color:rgba(0,0,0,0);}\
                     QScrollBar::add-line:vertical{subcontrol-origin:margin;border:0px solid green;height:13px}")

        self.history_widget = Historical_Insatallation_widget(self.width()-self.space*2,self.height()-self.btn_widget.height()-20,self)
        self.history_widget.move(int((self.width()-self.history_widget.width())/2),int((self.height()-self.btn_widget.height()-self.history_widget.height())/2+self.btn_widget.height()))
        self.history_widget.setStyleSheet("QWidget{border-radius: 0px;}")
        self.history_widget.hide()
        self.scrollArea2 = QScrollArea(self)
        self.scrollArea2.setWidget(self.history_widget)
        self.scrollArea2.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
        self.scrollArea2.horizontalScrollBar().setEnabled(False)
        self.scrollArea2.setVerticalScrollBarPolicy(Qt.ScrollBarAsNeeded)
        self.scrollArea2.setGeometry(int((self.width() - self.history_widget.width()) / 2), int((self.height() - self.btn_widget.height() - self.history_widget.height()) / 2 + self.btn_widget.height()),int(self.history_widget.width() + self.space - 10),self.history_widget.height())
        self.scrollArea2.verticalScrollBar().setStyleSheet("QScrollBar:vertical{margin:0px 0px 0px 0px;background-color:transparent;border:0px;width:6px;border-radius: 3px;}\
                             QScrollBar::handle:vertical{background-color:#C2C2C2;width:6px;border-radius:3px;} QScrollBar::handle:vertical:hover{background-color:#8F9399;opacity:0.1;width:6px;border-radius:3px;}  QScrollBar::handle:vertical:pressed{background-color:#8F9399;width:6px;border-radius:3px;}\
                             QScrollBar::sub-line:vertical{subcontrol-origin:margin;border:0px solid red;height:13px}\
                             QScrollBar::up-arrow:vertical{subcontrol-origin:margin;background-color:rgba(0,0,0,0);height:13px}\
                             QScrollBar::sub-page:vertical{background-color:transparent;}\
                             QScrollBar::add-page:vertical{background-color:transparent;}\
                             QScrollBar::down-arrow:vertical{background-color:rgba(0,0,0,0);}\
                             QScrollBar::add-line:vertical{subcontrol-origin:margin;border:0px solid green;height:13px}")
        self.scrollArea2.verticalScrollBar().valueChanged.connect(self.m_parent.mw.slot_scrollbar_valuechange)
        self.scrollArea2.hide()
        self.set_show_dark_mode()

    #
    #
    #
    def set_show_dark_mode(self):
        if(Globals.THEME_COLOR == 0):
            self.type_name_label.setStyleSheet(
                "QLabel{font-size: 24px;font-weight: 600;color: #303133;line-height: 42px;}")
            self.all_check.setStyleSheet(
                "QPushButton{border:0px;font-size: 14px;font-weight: 500;color: #3790FA;line-height: 20px;border:0px solid #ff0000;}QPushButton:hover{background: rgba(55, 144, 250, 0.12);border-radius: 12px;}QPushButton:pressed{background: rgba(55, 144, 250, 0.12);border-radius: 12px;}")
            self.download_all_check.setStyleSheet(
                "QPushButton{border:0px;font-size: 14px;font-weight: 500;color: #3790FA;line-height: 20px;border:0px solid #ff0000;}QPushButton:hover{background: rgba(55, 144, 250, 0.12);border-radius: 12px;}QPushButton:pressed{background: rgba(55, 144, 250, 0.12);border-radius: 12px;}")
            self.all_select_btn.setStyleSheet(
                "QPushButton{font-size: 14px;border:0px;font-weight: 500;color: #606265;line-height: 20px;}QPushButton:hover{background: rgba(55, 144, 250, 0.12);color: #3790FA;border-radius: 12px;}PushButton:pressed{background: rgba(55, 144, 250, 0.12);color: #3790FA;border-radius: 12px;}")
            self.text_prompt_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #BBBDCA;line-height: 24px;}")
            self.border.setStyleSheet("QLabel{background-color:rgba(0,0,0,0.08);}")
            self.scrollArea.verticalScrollBar().setStyleSheet("QScrollBar:vertical{margin:0px 0px 0px 0px;background-color:transparent;border:0px;width:6px;border-radius: 3px;}\
                                 QScrollBar::handle:vertical{background-color:#C2C2C2;width:6px;border-radius:3px;} QScrollBar::handle:vertical:hover{background-color:#8F9399;opacity:0.1;width:6px;border-radius:3px;}  QScrollBar::handle:vertical:pressed{background-color:#8F9399;width:6px;border-radius:3px;}\
                                 QScrollBar::sub-line:vertical{subcontrol-origin:margin;border:0px solid red;height:13px}\
                                 QScrollBar::up-arrow:vertical{subcontrol-origin:margin;background-color:rgba(0,0,0,0);height:13px}\
                                 QScrollBar::sub-page:vertical{background-color:transparent;}\
                                 QScrollBar::add-page:vertical{background-color:transparent;}\
                                 QScrollBar::down-arrow:vertical{background-color:rgba(0,0,0,0);}\
                                 QScrollBar::add-line:vertical{subcontrol-origin:margin;border:0px solid green;height:13px}")
            self.scrollArea1.verticalScrollBar().setStyleSheet("QScrollBar:vertical{margin:0px 0px 0px 0px;background-color:transparent;border:0px;width:6px;border-radius: 3px;}\
                                 QScrollBar::handle:vertical{background-color:#C2C2C2;width:6px;border-radius:3px;} QScrollBar::handle:vertical:hover{background-color:#8F9399;opacity:0.1;width:6px;border-radius:3px;}  QScrollBar::handle:vertical:pressed{background-color:#8F9399;width:6px;border-radius:3px;}\
                                 QScrollBar::sub-line:vertical{subcontrol-origin:margin;border:0px solid red;height:13px}\
                                 QScrollBar::up-arrow:vertical{subcontrol-origin:margin;background-color:rgba(0,0,0,0);height:13px}\
                                 QScrollBar::sub-page:vertical{background-color:transparent;}\
                                 QScrollBar::add-page:vertical{background-color:transparent;}\
                                 QScrollBar::down-arrow:vertical{background-color:rgba(0,0,0,0);}\
                                 QScrollBar::add-line:vertical{subcontrol-origin:margin;border:0px solid green;height:13px}")
            self.scrollArea2.verticalScrollBar().setStyleSheet("QScrollBar:vertical{margin:0px 0px 0px 0px;background-color:transparent;border:0px;width:6px;border-radius: 3px;}\
                                 QScrollBar::handle:vertical{background-color:#C2C2C2;width:6px;border-radius:3px;} QScrollBar::handle:vertical:hover{background-color:#8F9399;opacity:0.1;width:6px;border-radius:3px;}  QScrollBar::handle:vertical:pressed{background-color:#8F9399;width:6px;border-radius:3px;}\
                                 QScrollBar::sub-line:vertical{subcontrol-origin:margin;border:0px solid red;height:13px}\
                                 QScrollBar::up-arrow:vertical{subcontrol-origin:margin;background-color:rgba(0,0,0,0);height:13px}\
                                 QScrollBar::sub-page:vertical{background-color:transparent;}\
                                 QScrollBar::add-page:vertical{background-color:transparent;}\
                                 QScrollBar::down-arrow:vertical{background-color:rgba(0,0,0,0);}\
                                 QScrollBar::add-line:vertical{subcontrol-origin:margin;border:0px solid green;height:13px}")
            self.loadinglabel.setMovie(self.loadingmove)
            self.loadingmove.start()
        else:
            self.type_name_label.setStyleSheet(
                "QLabel{font-size: 24px;font-weight: 600;color: #F9F9F9;line-height: 42px;}")
            self.all_check.setStyleSheet(
                "QPushButton{border:0px;font-size: 14px;font-weight: 500;color: #62666C;line-height: 20px;border:0px solid #ff0000;}QPushButton:hover{background: rgba(55, 144, 250, 0.12);border-radius: 12px;}QPushButton:pressed{background: rgba(55, 144, 250, 0.12);border-radius: 12px;}")
            self.download_all_check.setStyleSheet(
                "QPushButton{border:0px;font-size: 14px;font-weight: 500;color: #3790FA;line-height: 20px;border:0px solid #ff0000;}QPushButton:hover{background: rgba(55, 144, 250, 0.12);border-radius: 12px;}QPushButton:pressed{background: rgba(55, 144, 250, 0.12);border-radius: 12px;}")
            self.all_select_btn.setStyleSheet(
                "QPushButton{font-size: 14px;border:0px;font-weight: 500;color: #F9F9F9;line-height: 20px;}QPushButton:hover{background: rgba(55, 144, 250, 0.12);color: #3790FA;border-radius: 12px;}PushButton:pressed{background: rgba(55, 144, 250, 0.12);color: #3790FA;border-radius: 12px;}")
            self.text_prompt_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #C0C4CC;line-height: 24px;}")
            self.border.setStyleSheet("QLabel{background-color:rgba(255,255,255,0.08);}")
            self.scrollArea.verticalScrollBar().setStyleSheet("QScrollBar:vertical{margin:0px 0px 0px 0px;background-color:transparent;border:0px;width:6px;border-radius: 3px;}\
                                 QScrollBar::handle:vertical{background-color:#6B6B6B;width:6px;border-radius:3px;} QScrollBar::handle:vertical:hover{background-color:#959595;opacity:0.1;width:6px;border-radius:3px;}  QScrollBar::handle:vertical:pressed{background-color:#959595;width:6px;border-radius:3px;}\
                                 QScrollBar::sub-line:vertical{subcontrol-origin:margin;border:0px solid red;height:13px}\
                                 QScrollBar::up-arrow:vertical{subcontrol-origin:margin;background-color:rgba(0,0,0,0);height:13px}\
                                 QScrollBar::sub-page:vertical{background-color:transparent;}\
                                 QScrollBar::add-page:vertical{background-color:transparent;}\
                                 QScrollBar::down-arrow:vertical{background-color:rgba(0,0,0,0);}\
                                 QScrollBar::add-line:vertical{subcontrol-origin:margin;border:0px solid green;height:13px}")
            self.scrollArea1.verticalScrollBar().setStyleSheet("QScrollBar:vertical{margin:0px 0px 0px 0px;background-color:transparent;border:0px;width:6px;border-radius: 3px;}\
                                 QScrollBar::handle:vertical{background-color:#6B6B6B;width:6px;border-radius:3px;} QScrollBar::handle:vertical:hover{background-color:#959595;opacity:0.1;width:6px;border-radius:3px;}  QScrollBar::handle:vertical:pressed{background-color:#959595;width:6px;border-radius:3px;}\
                                 QScrollBar::sub-line:vertical{subcontrol-origin:margin;border:0px solid red;height:13px}\
                                 QScrollBar::up-arrow:vertical{subcontrol-origin:margin;background-color:rgba(0,0,0,0);height:13px}\
                                 QScrollBar::sub-page:vertical{background-color:transparent;}\
                                 QScrollBar::add-page:vertical{background-color:transparent;}\
                                 QScrollBar::down-arrow:vertical{background-color:rgba(0,0,0,0);}\
                                 QScrollBar::add-line:vertical{subcontrol-origin:margin;border:0px solid green;height:13px}")
            self.scrollArea2.verticalScrollBar().setStyleSheet("QScrollBar:vertical{margin:0px 0px 0px 0px;background-color:transparent;border:0px;width:6px;border-radius: 3px;}\
                                 QScrollBar::handle:vertical{background-color:#6B6B6B;width:6px;border-radius:3px;} QScrollBar::handle:vertical:hover{background-color:#959595;opacity:0.1;width:6px;border-radius:3px;}  QScrollBar::handle:vertical:pressed{background-color:#959595;width:6px;border-radius:3px;}\
                                 QScrollBar::sub-line:vertical{subcontrol-origin:margin;border:0px solid red;height:13px}\
                                 QScrollBar::up-arrow:vertical{subcontrol-origin:margin;background-color:rgba(0,0,0,0);height:13px}\
                                 QScrollBar::sub-page:vertical{background-color:transparent;}\
                                 QScrollBar::add-page:vertical{background-color:transparent;}\
                                 QScrollBar::down-arrow:vertical{background-color:rgba(0,0,0,0);}\
                                 QScrollBar::add-line:vertical{subcontrol-origin:margin;border:0px solid green;height:13px}")
            self.loadinglabel.setMovie(self.loadingmove_dark)
            self.loadingmove_dark.start()

    #
    #函数：重新设置界面的位置
    def re_move(self):
        self.btn_widget.setFixedSize(self.width() - self.space * 2, 114)
        self.btn_widget.move(int((self.width() - self.btn_widget.width()) / 2), 0)
        self.downloading_btn.move(int((self.btn_widget.width() - self.downloading_btn.width() * 4 - 12 * 3) / 2), 20)
        self.downloading_num_label.move(int((self.btn_widget.width() - self.downloading_btn.width() * 4 - 12 * 3) / 2) + self.downloading_btn.width() - 10,13)
        self.update_btn.move(self.downloading_btn.x() + self.downloading_btn.width() + 12, 20)
        self.update_tip_spot.move(self.update_btn.x() + self.update_btn.width() - 10, self.update_btn.y() - 3)
        self.update_num_label.move(
            self.downloading_btn.x() + self.update_btn.width() + 12 + self.update_btn.width() - 10, 13)
        self.uninstall_btn.move(self.update_btn.x() + self.update_btn.width() + 12, 20)
        self.installed_btn.move(self.uninstall_btn.x() + self.uninstall_btn.width() + 12, 20)
        self.type_name_label.move(0, self.installed_btn.y() + 18)
        self.all_check.move(self.btn_widget.width() - self.all_check.width(),self.type_name_label.y() + self.type_name_label.height() + 2 - self.all_check.height())
        self.download_all_check.move(self.btn_widget.width() - self.download_all_check.width(),
                                     self.type_name_label.y() + self.type_name_label.height() + 2 - self.download_all_check.height())
        self.all_select_btn.move(self.all_check.x() - 20 - self.all_select_btn.width(), self.all_check.y())
        self.border.setFixedSize(self.btn_widget.width(), 1)
        self.border.move(0, self.type_name_label.y() + self.type_name_label.height() + 10)
        self.app_widget.resize(self.width() - self.space * 2, self.height() - self.btn_widget.height())
        self.app_widget.move(int((self.width() - self.app_widget.width()) / 2), int((self.height() - self.btn_widget.height() - self.app_widget.height()) / 2 + self.btn_widget.height()))
        self.scrollArea.setGeometry(self.btn_widget.x() + self.border.x(), int((self.height() - self.btn_widget.height() - self.app_widget.height()) / 2 + self.btn_widget.height()),
                                    self.app_widget.width() + self.space - 10, self.app_widget.height() - 10)
        self.downloading_widget.resize(self.width() - self.space * 2, self.height() - self.btn_widget.height())
        self.downloading_widget.move(int((self.width() - self.downloading_widget.width()) / 2), int((self.height() - self.btn_widget.height() - self.downloading_widget.height()) / 2 + self.btn_widget.height()))
        self.no_app_tip_label.move(int((self.width() - self.no_app_tip_label.width()) / 2),
                                   int((self.height() - self.no_app_tip_label.height()) / 2))
        self.text_prompt_label.move(int((self.width() - self.text_prompt_label.width()) / 2),
                                             self.no_app_tip_label.y() + self.no_app_tip_label.height() + 10)
        self.loadinglabel.move(int((self.width() - self.loadinglabel.width()) / 2),
                               int((self.height() - self.loadinglabel.height()) / 2))
        self.scrollArea1.setGeometry(int(self.btn_widget.x() + self.border.x()), int((self.height() - self.btn_widget.height() - self.downloading_widget.height()) / 2 + self.btn_widget.height()),
                                     self.downloading_widget.width() + self.space - 10,
                                     self.downloading_widget.height() - 10)

        self.history_widget.setFixedSize(self.width() - self.space * 2, self.height() - self.btn_widget.height()-20)
        self.scrollArea2.setGeometry(int(self.btn_widget.x() + self.border.x()), int((self.height() - self.btn_widget.height() - self.app_widget.height()) / 2 + self.btn_widget.height()),
                                    self.history_widget.width() + self.space - 10, self.history_widget.height())
        self.history_widget.re_move()
        # if(self.type_name_label.text() == _("Onload")):
        self.reload_card(self.downloading_widget,self.scrollArea1)
        if(self.type_name_label.text() == _("Installation")):
            self.reload_card(self.history_widget.app_card_widget, self.history_widget)
            if(len(self.history_widget.app_card_widget.children()) == 0):
                pass
            else:
                self.history_widget.setFixedHeight(self.history_widget.label_local.y() + self.history_widget.label_local.height() + self.history_widget.app_card_widget.height() + 30)
        else:
            self.reload_card(self.app_widget, self.scrollArea)


    #
    #函数：重新设置卡片
    #
    def reload_card(self,widget,scrollArea):
        cards = widget.children()
        if (len(cards) != 0):
            h_num = int(widget.width()/(self.card_width+self.card_space))
            get_card_width = int((widget.width() - (self.card_space * (h_num - 1)) - 20) / h_num)
            proportion = get_card_width / widget.width()
            get_card_height = self.card_height
            v_num = 0
            num = 0
            for i in range(len(cards)):
                card = cards[i]
                card.resize(get_card_width,get_card_height)
                card.re_move()
                if (num < h_num):
                    if (num == 0):
                        card.move(0, 20 + (20 + card.height()) * v_num)
                        widget.resize(widget.width(), 20 + (20 + card.height()) * (v_num + 1))
                    else:
                        card.move(num * (card.width() + self.card_space) , 20 + (20 + card.height()) * v_num)
                    num = num + 1
                else:
                    num = 0
                    v_num = v_num + 1
                    if (num == 0):
                        card.move(0, 20 + (20 + card.height()) * v_num)
                        widget.resize(widget.width(),  (20 + card.height()) * (v_num + 1))
                    else:
                        card.move(num * (card.width() + self.card_space), 20 + (20 + card.height()) * v_num)
                    num = num + 1

    #
    # 函数：处理点击分类界面的类型按钮
    #
    def slot_clicked_btn(self, btn_name):
        self.click_type_btn.emit(btn_name)

    #
    # 函数：绘制btn按钮
    # 当返回False时表示没有其他按钮是按下状态，所以这个按钮不能取消按下状态
    #
    def paint_btn(self):
        if (self.downloading_btn.is_clicked == True):
            self.downloading_btn.is_clicked = False
            self.downloading_btn.leave_btn.emit(0)
        elif (self.update_btn.is_clicked == True):
            self.update_btn.is_clicked = False
            self.update_btn.leave_btn.emit(0)
        elif (self.uninstall_btn.is_clicked == True):
            self.uninstall_btn.is_clicked = False
            self.uninstall_btn.leave_btn.emit(0)
        elif (self.installed_btn.is_clicked == True):
            self.installed_btn.is_clicked = False
            self.installed_btn.leave_btn.emit(0)
        else:
            return False
        return True

    #
    # 函数名:设置滚动条起始位置
    # Function:set verticalSscrollBar starting point
    #
    def scrollToTop(self):
        vsb = self.scrollArea.verticalScrollBar()
        vsb.setValue(0)

    # 鼠标进入事件

    def enterEvent(self, event):
        self.status = BUTTON_ENTER
        self.scrollArea.verticalScrollBar().show()
        # self.scrollArea.show()


    #
    # 函数：鼠标离开事件
    #

    def leaveEvent(self, event):
        self.status = BUTTON_LEAVE
        self.scrollArea.verticalScrollBar().hide()


    #
    # 函数：鼠标按下事件
    #
    def mousePressEvent(self, event):
        if event.button() == Qt.LeftButton:
            self.m_parent.mw.hide_tip_widget()
            self.status = BUTTON_PRESSED
        else:
            event.ignore()



#!/usr/bin/python3
# -*- coding: utf-8 -*-

from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import QFrame,QWidget,QLabel
import math
import gettext
from ui.systembutton import *
from models.globals import *
from utils.commontools import *
from utils.run import *
from models.enums import UKSC_CACHE_DIR
gettext.bindtextdomain("kylin-software-center", "/usr/share/locale")
gettext.textdomain("kylin-software-center")
_ = gettext.gettext


class Contact_Us_Widget(QFrame):
    def __init__(self,mw,parent=None):
        QFrame.__init__(self,parent)
        self.mw = mw
        self.mouse_press = False
        self.setFixedSize(420+20,560+20)
        self.paintEvent = self.set_paintEvent
        self.setWindowFlags(Qt.FramelessWindowHint|Qt.Tool)
        self.setWindowTitle(_("Software Store"))
        self.setAttribute(Qt.WA_TranslucentBackground)

        self.widget = QWidget(self)
        self.widget.resize(self.width()-20,self.height()-20)
        self.widget.move(10,10)
        # self.widget.setStyleSheet("QWidget{border-radius:6px;background-color:#ffffff;border: 1px solid rgba(38, 38, 38, 0.15);}")

        self.logo_icon_label = QPushButton(self.widget)
        self.logo_icon_label.setFixedSize(24, 24)
        # self.logo_icon_label.setFrameShape(QFrame.NoFrame)
        self.logo_icon_label.setAutoFillBackground(True)
        # self.logo_icon_label.setScaledContents(True)
        iconpath = get_title_icon(Globals.APPNAME)
        self.logo_icon_label.setIcon(QIcon(iconpath))
        self.logo_icon_label.setIconSize(QSize(24, 24))
        self.logo_icon_label.setStyleSheet("QPushButton{background:transparent;border:0px;}")
        self.logo_icon_label.move(8, 8)
        self.logo_icon_label.show()

        self.titel_label = QLabel(self.widget)
        self.titel_label.setFixedSize(200,24)
        # self.titel_label.adjustSize()
        # self.titel_label.setFixedWidth(160)
        self.titel_label.setAttribute(Qt.WA_TranslucentBackground)
        self.titel_label.setStyleSheet("QLabel{font-size: 14px;color: #1B1B1B;}")
        self.titel_label.setText(_("Software Store"))
        self.titel_label.setAlignment(Qt.AlignVCenter)
        self.titel_label.adjustSize()
        self.titel_label.move(self.logo_icon_label.x()+self.logo_icon_label.width()+8,8)
        self.titel_label.show()

        self.close_btn = QPushButton(self.widget)
        self.close_btn.resize(30,30)
        self.close_btn.setFocusPolicy(Qt.NoFocus)
        self.close_btn.move(self.widget.width()-4-self.close_btn.width(),4)
        # self.close_btn.clicked.connect(self.slot_click_close_btn)
        self.close_btn.installEventFilter(self)
        self.close_btn.setToolTip(_("close"))

        self.big_logo = QLabel(self.widget)
        self.big_logo.setFixedSize(96,96)
        iconpath = get_big_icon_path(Globals.APPNAME)
        # label_pixmap = QPixmap(iconpath)
        # self.big_logo.setPixmap(label_pixmap)
        self.big_logo.setStyleSheet("QLabel{border-image: url("+iconpath+") 0 0 0 0 stretch strectch;}")
        # self.big_logo.setStyleSheet("QLabel{background:transparent;border:0px;}")
        self.big_logo.move(int((self.widget.width()-self.big_logo.width())/2),60)

        self.app_name_label = QLabel(self.widget)
        self.app_name_label.setFixedHeight(28)
        self.app_name_label.setStyleSheet("QLabel{font-size: 18px;font-weight: 500;color: #262626;line-height: 28px;}")
        self.app_name_label.setText(_("Software Store"))
        self.app_name_label.adjustSize()
        self.app_name_label.setAlignment(Qt.AlignVCenter)
        self.app_name_label.move(int((self.widget.width()-self.app_name_label.width())/2),self.big_logo.height()+self.big_logo.y()+16)

        self.app_version_label = QLabel(self.widget)
        self.app_version_label.setFixedHeight(34)
        self.app_version_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #595959;line-height: 24px;}")
        self.app_version_label.setText(_("versions:") + Globals.UKSC_VERSION.split("kylin")[0])
        self.app_version_label.adjustSize()
        self.app_version_label.setAlignment(Qt.AlignVCenter)
        self.app_version_label.move(int((self.widget.width() - self.app_version_label.width())/2),self.app_name_label.y()+self.app_name_label.height()+12)

        self.discription_label = QLabel(self.widget)
        self.discription_label.setFixedWidth(self.widget.width()-32*2)
        self.discription_label.setWordWrap(True)
        # self.discription_label.setAlignment(Qt.AlignHCenter)
        # self.discription_label.setAlignment(Qt.AlignLeft | Qt.AlignVCenter)
        self.discription_label.setStyleSheet("QLabel{font-size: 14px;color: #595959;line-height: 24px;text-align:justify;}")
        # self.discription_label.setText(_("软件商店是一款内容丰富的图形化软件管理工具，支持新品上架、热门应用推荐功能，提供软件搜索、下载、安装、更新、卸载等一站式软件服务。"))
        self.discription_label.setText(_("Software store is a graphical software management tool with rich content. It supports the recommendation of new products and popular applications, and provides one-stop software services such as software search, download, installation, update and uninstall."))
        # self.discription_label.setText("软件商店是一款内容丰富的图形化软件管理工具，支持新品上架、热门应用等推荐功能，提供软件搜索、下载、安装、更新、卸载等一站式软件服务。")
        self.discription_label.adjustSize()
        self.discription_label.move(int((self.widget.width()-self.discription_label.width())/2),self.app_version_label.y()+self.app_version_label.height()+12)


        self.contact_us_label = QLabel(self.widget)
        self.contact_us_label.setStyleSheet("QLabel{font-size: 14px;color: #595959;line-height: 24px;text-align:justify;}")
        # self.contact_us_label.setFixedWidth(self.widget.width()-32*2)
        # self.contact_us_label.setWordWrap(True)
        self.contact_us_label.setText(_("Service and support team: ") +  '<a href="mailto://sopport@kylinos.cn\"'
                                                                         'style=\"color:#595959;\">'
                                                                         'support@kylinos.cn</a>')
        self.contact_us_label.adjustSize()
        self.contact_us_label.linkActivated.connect(self.link_handler)
        self.contact_us_label.setContextMenuPolicy(Qt.NoContextMenu)
        self.contact_us_label.move(32, self.discription_label.y() + self.discription_label.height() + 20)
        # self.contact_us_label.move(int((self.widget.width()-self.contact_us_label.width())/2), self.discription_label.y() + self.discription_label.height() + 12)
        # self.contact_us_label.setOpenExternalLinks(True)
        # self.contact_us_label.setTextInteractionFlags(Qt.TextSelectableByMouse)
        # self.contact_us_label.setText(_("Service and support team: ") + Globals.SUPPORT_MAILBOX)

        self.disclaimers_label = QLabel(self.widget)
        self.disclaimers_label.setStyleSheet(
            "QLabel{font-size: 14px;color: #595959;line-height: 24px;text-align:justify;}")
        # self.disclaimers_label.setFixedWidth(self.widget.width() - 32 * 2)
        # self.disclaimers_label.setWordWrap(True)
        self.disclaimers_label.setText(_("Disclaimers:") + '<a href="Disclaimer\"''style=\"color:#595959;\">'
                                                                        '' + "《" + _("Kylin Software Store Disclaimer") + "》" + ' </a>')
        self.disclaimers_label.linkActivated.connect(self.click_disclaimers)
        self.disclaimers_label.adjustSize()
        # self.disclaimers_label.move(int((self.widget.width()-self.disclaimers_label.width())/2),self.contact_us_label.y()+self.contact_us_label.height()+5)
        self.disclaimers_label.move(self.contact_us_label.x(),self.contact_us_label.y()+self.contact_us_label.height()+5)
        # self.disclaimers_label.hide()

        self.widget.setFixedHeight(self.disclaimers_label.y()+self.disclaimers_label.height()+40)
        self.setFixedHeight(self.widget.height()+20)
        self.slot_show_dark_mode()

    #
    # 函数：重新设置icon
    #
    def change_icon_show(self):
        iconpath = get_title_icon(Globals.APPNAME)
        self.logo_icon_label.setIcon(QIcon(iconpath))
        self.logo_icon_label.setIconSize(QSize(24, 24))
        self.logo_icon_label.setStyleSheet("QPushButton{background:transparent;border:0px;}")
        # self.logo_icon_label.setIcon(QIcon.fromTheme("kylin-software-center"))
        iconpath = get_big_icon_path(Globals.APPNAME)
        self.big_logo.setStyleSheet("QLabel{border-image: url(" + iconpath + ") 0 0 0 0 stretch strectch;}")
        self.big_logo.hide()
        self.big_logo.show()


    #
    #函数：点击免责说明
    #
    def click_disclaimers(self,text):
        url = Globals.DISCLAIMERS
        webbrowser_open_url(url)

    #
    #函数：点击发送邮件
    #
    def link_handler(self,url):
        # webbrowser_open_url(url)
        # os.popen("evolution")
        # QDesktopServices.openUrl(QUrl(url))
        try:
            config_home = UKSC_CACHE_DIR.rsplit("/", 2)[0] + "/.config/"
            mimeapps_path = config_home + "mimeapps.list"
            with open(mimeapps_path, "r", encoding="utf-8") as mine_file:
                for line in mine_file.readlines():
                    if line.find("x-scheme-handler/mailto") != -1:
                        print(line)
                        mailto_name = (line.rsplit("=", 1)[1]).rsplit(".", 1)[0]
                        if Globals.DEBUG_SWITCH:
                            print("broswer name: %s" % mailto_name)
                        break
            if (mailto_name == "org.gnome.Evolution"):
                try:
                    app = self.mw.detailwidget.ca["evolution"]
                except:
                    app = None
                if(app != None):
                    if (app.candidate != None and app.is_installed == True):
                        self.mw.ask_thread.run_iface.call_run_app("evolution mailto:")
                        return
            elif(mailto_name == "thunderbird"):
                try:
                    app = self.mw.detailwidget.ca["evolution"]
                except:
                    app = None
                if(app != None):
                    if (app.candidate != None and app.is_installed == True):
                        self.mw.ask_thread.run_iface.call_run_app("thunderbird -compose")
                        return
            elif (mailto_name == "claws-mail"):
                try:
                    app = self.mw.detailwidget.ca["claws-mail"]
                except:
                    app = None
                if (app != None):
                    if (app.candidate != None and app.is_installed == True):
                        self.mw.ask_thread.run_iface.call_run_app("claws-mail")
                        return
        except:
                pass
        try:
            app = self.mw.detailwidget.ca["evolution"]
            if(app.candidate != None and app.is_installed == True):
                # cmd = run_app("evolution")
                # self.mw.ask_thread.run_iface.call_run_app(cmd)
                self.mw.ask_thread.run_iface.call_run_app("evolution mailto:")
            else:
                try:
                    app = self.mw.detailwidget.ca["thunderbird"]
                    if (app.candidate != None and app.is_installed == True):
                        # cmd =  run_app("thunderbird")
                        self.mw.ask_thread.run_iface.call_run_app("thunderbird -compose")
                    else:
                        try:
                            app = self.mw.detailwidget.ca["claws-mail"]
                            if (app.candidate != None and app.is_installed == True):
                                # cmd = run_app("claws-mail")
                                # self.mw.ask_thread.run_iface.call_run_app(cmd)
                                self.mw.ask_thread.run_iface.call_run_app("claws-mail")
                        except:
                            pass
                except:
                    try:
                        app = self.mw.detailwidget.ca["claws-mail"]
                        if (app.candidate != None and app.is_installed == True):
                            # cmd = run_app("claws-mail")
                            # self.mw.ask_thread.run_iface.call_run_app(cmd)
                            self.mw.ask_thread.run_iface.call_run_app("claws-mail")
                    except:
                        pass
        except:
            try:
                app = self.mw.detailwidget.ca["thunderbird"]
                if (app.candidate != None and app.is_installed == True):
                    # cmd = run_app("thunderbird")
                    # self.mw.ask_thread.run_iface.call_run_app(cmd)
                    self.mw.ask_thread.run_iface.call_run_app("thunderbird -compose")
                else:
                    try:
                        app = self.mw.detailwidget.ca["claws-mail"]
                        if (app.candidate != None and app.is_installed == True):
                            # cmd = run_app("claws-mail")
                            # self.mw.ask_thread.run_iface.call_run_app(cmd)
                            self.mw.ask_thread.run_iface.call_run_app("claws-mail")
                    except:
                        pass
            except:
                try:
                    app = self.mw.detailwidget.ca["claws-mail"]
                    if (app.candidate != None and app.is_installed == True):
                        # cmd = run_app("claws-mail")
                        self.mw.ask_thread.run_iface.call_run_app("claws-mail")
                except:
                    pass

    #
    #函数：处理主题颜色的显示
    #
    def slot_show_dark_mode(self):
        if(Globals.THEME_COLOR == 0 ):
            if(Globals.RIGHT_ANGLE):
                self.widget.setStyleSheet("QWidget{background-color:#ffffff;}")
                self.setStyleSheet("QFrame{background-color:#ffffff;}")
            else:
                self.widget.setStyleSheet("QWidget{border-radius:12px;background-color:#ffffff;}")
                self.setStyleSheet("QFrame{border-radius:12px;background-color:#ffffff;}")
            self.titel_label.setStyleSheet("QLabel{font-size: 14px;color: #1B1B1B;}")
            self.app_name_label.setStyleSheet("QLabel{font-size: 18px;color: #1B1B1B;line-height: 28px;}")
            self.app_version_label.setStyleSheet("QLabel{font-size: 14px;color: #595959;line-height: 24px;}")
            self.discription_label.setStyleSheet("QLabel{font-size: 14px;color: #595959;line-height: 24px;text-align:justify;}")
            self.contact_us_label.setStyleSheet("QLabel{font-size: 14px;color: #595959;line-height: 24px;text-align:justify;}")
            self.contact_us_label.setText(_("Service and support team: ") + '<a href="mailto://sopport@kylinos.cn\"'
                                                                            'style=\"color:#595959;\">'
                                                                            'support@kylinos.cn</a>')
            self.close_btn.setStyleSheet("QPushButton{border-radius: 4px;border:0px;border-image:url('res/close1.png')}")
            self.disclaimers_label.setStyleSheet(
                "QLabel{font-size: 14px;color: #595959;line-height: 24px;text-align:justify;}")
            self.disclaimers_label.setText(_("Disclaimers:") + '<a href="Disclaimer\"'
                                                                'style=\"color:#595959;\">'
                                                                '' + "《" + _("Kylin Software Store Disclaimer") + "》" + ' </a>')
        else:
            if (Globals.RIGHT_ANGLE):
                self.widget.setStyleSheet("QWidget{background-color:#3D3D41;}")
                self.setStyleSheet("QFrame{background-color:#3D3D41;}")
            else:
                self.setStyleSheet("QFrame{border-radius:12px;background-color:#3D3D41;}")
                self.widget.setStyleSheet("QWidget{border-radius:12px;background-color:#3D3D41;}")
            self.titel_label.setStyleSheet("QLabel{font-size: 14px;color: #8F9399;}")
            self.app_name_label.setStyleSheet("QLabel{font-size: 18px;color: #C0C4CC;line-height: 28px;}")
            self.app_version_label.setStyleSheet("QLabel{font-size: 14px;color: #C0C4CC;line-height: 24px;}")
            self.discription_label.setStyleSheet("QLabel{font-size: 14px;color: #C0C4CC;line-height: 24px;text-align:justify;}")
            self.contact_us_label.setStyleSheet("QLabel{font-size: 14px;color: #C0C4CC;line-height: 24px;text-align:justify;}")
            self.contact_us_label.setText(_("Service and support team: ") + '<a href="mailto://sopport@kylinos.cn\"'
                                                                            'style=\"color:#C0C4CC;\">'
                                                                            'support@kylinos.cn</a>')
            self.disclaimers_label.setStyleSheet(
                "QLabel{font-size: 14px;color: #C0C4CC;line-height: 24px;text-align:justify;}")
            self.disclaimers_label.setText(_("Disclaimers:") + '<a href="Disclaimer\"'
                                                                        'style=\"color:#C0C4CC;\">'
                                                                        ''+"《"+ _("Kylin Software Store Disclaimer")+"》"+' </a>')

            self.close_btn.setStyleSheet("QPushButton{border-radius: 4px;border:0px;border-image:url('res/common-close-white.png')}")
        # QApplication.processEvents()


    #
    #函数：处理点击关闭按钮
    #
    def slot_click_close_btn(self):
        if (Globals.THEME_COLOR == 0):
            self.close_btn.setStyleSheet(
                "QPushButton{border-radius: 4px;border:0px;border-image:url('res/close1.png')}")
        else:
            self.close_btn.setStyleSheet(
                "QPushButton{border-radius: 4px;border:0px;border-image:url('res/res/common-close-white.png.png')}")
        self.hide()
        QApplication.setActiveWindow(self.mw)

    def eventFilter(self, widget, event):
        if(hasattr(self,"close_btn")):
            if (widget == self.close_btn and event.type() == event.MouseButtonRelease):
                self.slot_click_close_btn()
                # return True
            elif (widget == self.close_btn and event.type() == event.HoverEnter):
                if (Globals.THEME_COLOR == 0):
                    self.close_btn.setStyleSheet("QPushButton:hover{border-radius: 4px;border:0px;border-image:url('res/close2.png')}")
                else:
                    self.close_btn.setStyleSheet("QPushButton{border-radius: 4px;border:0px;border-image:url('res/hover-close.png')}")
            elif (widget == self.close_btn and event.type() == event.HoverLeave):
                if (Globals.THEME_COLOR == 0):
                    self.close_btn.setStyleSheet("QPushButton{border-radius: 4px;border:0px;border-image:url('res/close1.png')}")
                else:
                    self.close_btn.setStyleSheet("QPushButton{border-radius: 4px;border:0px;border-image:url('res/common-close-white.png')}")
            elif (widget == self.close_btn and event.type() == event.MouseButtonPress):
                if (Globals.THEME_COLOR == 0):
                    self.close_btn.setStyleSheet("QPushButton:hover{border-radius: 4px;border:0px;border-image:url('res/close3.png')}")
                else:
                    self.close_btn.setStyleSheet("QPushButton{border-radius: 4px;border:0px;border-image:url('res/clicked-close.png')}")
        return False


    # 函数：重绘函数
    # is_clicked_second_menu:如果是点击第二级目录则不会影藏一级目录
    #
    def set_paintEvent(self, event):
        painter = QPainter(self)
        m_defaultBackgroundColor = QColor(qRgb(192, 192, 192))
        m_defaultBackgroundColor.setAlpha(50)
        path = QPainterPath()
        path.setFillRule(Qt.WindingFill)
        path.addRoundedRect(10, 10, self.width() - 20, self.height() - 20, 12, 12)

        painter.setRenderHint(QPainter.Antialiasing, True)
        painter.fillPath(path, QBrush(QColor(m_defaultBackgroundColor.red(),
                                             m_defaultBackgroundColor.green(),
                                             m_defaultBackgroundColor.blue())))

        color = QColor(0, 0, 0, 16)
        i = 0
        while i < 4:
            path = QPainterPath()
            path.setFillRule(Qt.WindingFill)
            path.addRoundedRect(10 - i, 10 - i, self.width() - (10 - i) * 2, self.height() - (10 - i) * 2, 12, 12)
            color.setAlpha(int(100 - math.sqrt(i) * 50))
            painter.setPen(color)
            painter.drawPath(path)
            i = i + 1

        painter.setRenderHint(QPainter.Antialiasing)

    #
    # 函数：实现无标题栏窗口拖动
    #
    def mousePressEvent(self, event):
        if (event.button() == Qt.LeftButton):
            self.mouse_press = True
            self.drag_pos = event.globalPos() - self.pos()
            event.accept()

    def mouseReleaseEvent(self, event):
        self.mouse_press = False
        self.setWindowOpacity(1)

    # def mouseMoveEvent(self, event):
    #     if (self.mouse_press):
    #         self.move_pos = event.globalPos()
    #         self.move(self.move_pos - self.drag_pos)
    #         self.setWindowOpacity(1)
    #         event.accept()



#!/usr/bin/python3
# -*- coding: utf-8 -*-

### BEGIN LICENSE

# Copyright (C) 2013 National University of Defense Technology(NUDT) & Kylin Ltd

# Author:
#     Kobe Lee<lixiang@ubuntukylin.com>
# Maintainer:
#     Shine Huang<shenghuang@ubuntukylin.com>

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import subprocess
import shutil
from PyQt5.QtCore import *
from PyQt5.QtNetwork import QNetworkAccessManager, QNetworkRequest
from models.enums import Signals
from models.globals import Globals
HOME_PATH = os.path.expandvars('$HOME')

#
# 函数：获取缓存目录
#
def generate_tmp_path(name):
    assert(isinstance(name, str))
    dest_path = HOME_PATH + "/.cache/uksc/"
    folder_path = dest_path + name
    if os.path.exists(folder_path):
        shutil.rmtree(folder_path)
    return dest_path

#
# 函数：解压win替换的资源包
#
def unzip_resource(package_file):
    unziped_dir = generate_tmp_path("uk-win")
    if unziped_dir[len(unziped_dir)-1] != "/":
        unziped_dir = unziped_dir + "/"
    subprocess.call(["unzip", package_file, "-d", unziped_dir])
    dest_dir = unziped_dir + "uk-win/"
    if not os.path.exists(dest_dir):
        if (Globals.DEBUG_SWITCH):
            print(("unzip '%s' to '%s' failed" % (package_file , unziped_dir)))
        return False
    else:
        if (Globals.DEBUG_SWITCH):
            print("unzip ok....")
        return True

class HttpDownLoad(QObject,Signals):

    def __init__(self, parent=None):
        QObject.__init__(self)
        self.mManager = QNetworkAccessManager()

    def sendDownLoadRequest(self, url):
        info = QFileInfo(url.path())
        fileName = info.fileName()
        if fileName == '':
            fileName = "/tmp/uk-win.zip"
        self.file = QFile(fileName)
        if not self.file.open(QIODevice.WriteOnly):
            self.file = None
            return
        self.startRequest(url)

    def startRequest(self, url):
        uk_path = HOME_PATH + "/.cache/uksc/uk-win/"
        if not os.path.exists(uk_path):
            self.reply = self.mManager.get(QNetworkRequest(url))
            self.reply.finished.connect(self.slot_http_finished)#下载完成
            self.reply.readyRead.connect(self.slot_http_ready_read)#有可用数据

    #save data
    def slot_http_ready_read(self):
        if self.file:
            self.file.write(self.reply.readAll())

    #finish download
    def slot_http_finished(self):
        self.file.flush()
        self.file.close()
        self.reply.deleteLater()
        self.reply = None
        self.file = None
        # unzip_resource("/tmp/uk-win.zip")
        self.unzip_img.emit()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'uksw.ui'
#
# Created: Mon Mar 10 10:08:03 2014
#      by: PyQt5 UI code generator 4.10.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui
from PyQt5.QtWidgets import *

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QApplication.translate(context, text, disambig)

class Ui_StarWidget(object):
    def setupUi(self, StarWidget):
        StarWidget.setObjectName(_fromUtf8("StarWidget"))
        StarWidget.resize(64, 16)
        self.star1 = QLabel(StarWidget)
        self.star1.setGeometry(QtCore.QRect(1, 1, 14, 14))
        self.star1.setText(_fromUtf8(""))
        self.star1.setObjectName(_fromUtf8("star1"))
        self.star2 = QLabel(StarWidget)
        self.star2.setGeometry(QtCore.QRect(18, 1, 14, 14))
        self.star2.setText(_fromUtf8(""))
        self.star2.setObjectName(_fromUtf8("star2"))
        self.star3 = QLabel(StarWidget)
        self.star3.setGeometry(QtCore.QRect(35, 1, 14,14))
        self.star3.setText(_fromUtf8(""))
        self.star3.setObjectName(_fromUtf8("star3"))
        self.star4 = QLabel(StarWidget)
        self.star4.setGeometry(QtCore.QRect(53, 1, 14,14))
        self.star4.setText(_fromUtf8(""))
        self.star4.setObjectName(_fromUtf8("star4"))
        self.star5 = QLabel(StarWidget)
        self.star5.setGeometry(QtCore.QRect(71, 1, 14,14))
        self.star5.setText(_fromUtf8(""))
        self.star5.setObjectName(_fromUtf8("star5"))
        self.retranslateUi(StarWidget)
        QtCore.QMetaObject.connectSlotsByName(StarWidget)

    #
    # 函数名:设置窗口标题
    # Function: set window title
    # 
    def retranslateUi(self, StarWidget):
        StarWidget.setWindowTitle(_translate("StarWidget", "Form", None))




from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
from ui.systembutton import *
from ui.systembutton import *
from models.enums import CONF_PATH
import datetime
import math
import configparser
import gettext
from ui.menubar import menu_list_widget
gettext.bindtextdomain("kylin-software-center", "/usr/share/locale")
gettext.textdomain("kylin-software-center")
_ = gettext.gettext

class Select_Widget(QWidget):
    click_item = pyqtSignal(QListWidgetItem)
    def __init__(self,width,height,item_num,item_name_list,need_icon,parent = None):
        QFrame.__init__(self, parent)
        self.w = width
        self.h = height
        self.item_num = item_num
        self.mouse_press = False
        self.item_name_list = item_name_list
        self.setMouseTracking(True)
        self.need_icon = need_icon
        self.init_ui()
        self.paintEvent = self.set_paintEvent

    def init_ui(self):
        self.resize(self.w+4+20,self.item_num*(self.h+2)+20)
        self.setWindowFlags(Qt.FramelessWindowHint)
        self.setAttribute(Qt.WA_TranslucentBackground)

        self.widget = QFrame(self)
        self.widget.resize(self.w+4,self.item_num*(self.h+2))
        self.widget.move(10,10)

        self.item_list = QListWidget(self.widget)
        self.item_list.setFocusPolicy(Qt.NoFocus)
        self.item_list.resize(self.w,self.item_num*(self.h+2))
        self.item_list.move(2,2)
        self.slot_show_dark_mode()
        for i_name in self.item_name_list:
            item = QListWidgetItem(self.item_list)
            # list_item_widget = menu_list_widget(self.w, self.h, i_name, True, False, self)
            if (self.need_icon == True):
                list_item_widget = menu_list_widget(self.w, self.h, i_name, False, True, self)
                list_item_widget.setFocusPolicy(Qt.NoFocus)
                list_item_widget.clicked_item.connect(self.slot_clicked_item)
                list_item_widget.enter_signal.connect(self.slot_enter_theme)
            else:
                list_item_widget = menu_list_widget(self.w, self.h, i_name, False, False, self)
                list_item_widget.setFocusPolicy(Qt.NoFocus)
                list_item_widget.clicked_item.connect(self.slot_clicked_item)
                # list_item_widget.leave_signal.connect(self.slot_leave_theme)
            self.item_list.addItem(item)
            self.item_list.setItemWidget(item, list_item_widget)
            self.check_item_color()

    def slot_show_dark_mode(self):
        if (Globals.THEME_COLOR == 0):
            if (Globals.RIGHT_ANGLE):
                self.setStyleSheet("QFrame{border:0px solid #ff0000;background-color:#ffffff;}")
                self.widget.setStyleSheet("QFrame{border:0px solid #ff0000;background-color:#ffffff;}")
            else:
                self.setStyleSheet("QFrame{border:0px solid #ff0000;background-color:#ffffff;border-radius: 8px;}")
                self.widget.setStyleSheet(
                    "QFrame{border:0px solid #ff0000;background-color:#ffffff;border-radius: 8px;}")
            self.item_list.setStyleSheet(
                "QListWidget{background-color:transparent;border:0px solid #cfcfcf;}QListWidget::item{height:30px;background-color:transparent;margin-top:0px;border:0px solid #cfcfcf;border-radius: 6px;}QListWidget::item:hover{background:#3790FA;border-radius: 6px;}")
        else:
            if (Globals.RIGHT_ANGLE):
                self.setStyleSheet("QFrame{border:0px solid #ff0000;background-color:#3D3D41;}")
                self.widget.setStyleSheet("QFrame{border:0px solid #ff0000;background-color:#3D3D41;}")
            else:
                self.setStyleSheet("QFrame{border:0px solid #ff0000;background-color:#3D3D41;border-radius: 8px;}")
                self.widget.setStyleSheet(
                    "QFrame{border:0px solid #ff0000;background-color:#3D3D41;border-radius: 8px;}")
            self.item_list.setStyleSheet(
                "QListWidget{background-color:#3D3D41;border:0px solid #cfcfcf;}QListWidget::item{height:30px;background-color:3D3D41;margin-top:0px;border:0px solid #cfcfcf;border-radius: 6px;}QListWidget::item:hover{background:#3790FA;border-radius: 6px;}")
        self.check_item_color()
        # QApplication.processEvents()


    def slot_clicked_item(self, item_name):
        item_count = self.item_list.count()
        for i in range(item_count):
            item = self.item_list.item(i)
            get_item_widget = self.item_list.itemWidget(item)
            if (get_item_widget.item_name_label.text() == item_name):
                self.click_item.emit(item)
            else:
                get_item_widget.icon_label.hide()

        # self.click_item.emit(item_name)

    def slot_enter_theme(self):
        for i in range(self.item_list.count()):
            item = self.item_list.item(i)
            item_widget = self.item_list.itemWidget(item)

    def slot_leave_theme(self):
        # self.hide()
        pass

    def check_item_color(self):
        for i in range(self.item_list.count()):
            item = self.item_list.item(i)
            get_item_widget = self.item_list.itemWidget(item)
            if (Globals.THEME_COLOR == 0):
                get_item_widget.item_name_label.setStyleSheet(
                    "QLabel{font-size: 14px;font-weight: 400;color: #303133;line-height: 14px;}")
                if (get_item_widget.primary_directory == False):
                    get_item_widget.icon_label.setStyleSheet(
                        "QLabel{background-image:url(./res/check2.png);background-color:transparent;}")
            else:
                get_item_widget.item_name_label.setStyleSheet(
                    "QLabel{font-size: 14px;font-weight: 400;color: #F9F9F9;line-height: 14px;}")
                if (get_item_widget.primary_directory == False):
                    get_item_widget.icon_label.setStyleSheet(
                        "QLabel{background-image:url(./res/check_dark.png);background-color:transparent;}")

    #
    # 函数：重绘函数
    #
    def set_paintEvent(self, event):
        painter = QPainter(self)
        m_defaultBackgroundColor = QColor(qRgb(192, 192, 192))
        m_defaultBackgroundColor.setAlpha(50)
        path = QPainterPath()
        path.setFillRule(Qt.WindingFill)
        path.addRoundedRect(10, 10, self.width() - 20, self.height() - 20, 8, 8)

        painter.setRenderHint(QPainter.Antialiasing, True)
        painter.fillPath(path, QBrush(QColor(m_defaultBackgroundColor.red(),
                                             m_defaultBackgroundColor.green(),
                                             m_defaultBackgroundColor.blue())))

        color = QColor(0, 0, 0, 20)
        i = 0
        while i < 4:
            path = QPainterPath()
            path.setFillRule(Qt.WindingFill)
            path.addRoundedRect(10 - i, 10 - i, self.width() - (10 - i) * 2, self.height() - (10 - i) * 2, 8, 8)
            color.setAlpha(int(100 - math.sqrt(i) * 50))
            painter.setPen(color)
            painter.drawPath(path)
            i = i + 1

        painter.setRenderHint(QPainter.Antialiasing)

    #
    # 函数：鼠标进入事件
    #
    def enterEvent(self, event):
        self.status = BUTTON_ENTER
        self.update()

    #
    # 函数：鼠标按下事件
    #
    def mousePressEvent(self, event):
        if (event.button() == Qt.LeftButton):
            self.setAttribute(Qt.WA_NoMouseReplay)
            self.mouse_press = True
            self.status = BUTTON_PRESSED
            self.update()

    #
    # 函数：鼠标释放事件
    #
    def mouseReleaseEvent(self, event):
        if (self.mouse_press and self.rect().contains(event.pos())):
            self.mouse_press = False
            self.status = BUTTON_ENTER
            self.update()

    #
    # 函数：鼠标离开事件
    #
    def leaveEvent(self, event):
        self.status = BUTTON_LEAVE
        self.update()
        self.hide()




#!/usr/bin/python3
# -*- coding: utf-8 -*-


from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
from models.globals import *
from models.enums import (BUTTON_ENTER, BUTTON_LEAVE, BUTTON_PRESSED, BUTTON_DISABLE)
import gettext
gettext.bindtextdomain("kylin-software-center", "/usr/share/locale")
gettext.textdomain("kylin-software-center")
_ = gettext.gettext

class SystemButton(QPushButton):

    leave_btn = pyqtSignal(int)
    enter_btn = pyqtSignal(int)
    click_btn = pyqtSignal(int)

    def __init__(self,is_setingbtn,is_minibtn,is_closebtn, parent = None):
        super(SystemButton,self).__init__(parent)
        #self.setStyleSheet("QPushButton{border-radius:4px;background-color:#3d6be5;}")
        self.mouse_press = False
        self.isclosebtn = is_closebtn
        self.issetingbtn=is_setingbtn
        self.isminibtn=is_minibtn
        self.setFocusPolicy(Qt.NoFocus)
        self.status = BUTTON_LEAVE
        self.setFixedSize(30, 30)
        self.click_btn.connect(self.paintbuttonevent)
        self.enter_btn.connect(self.paintbuttonevent)
        self.leave_btn.connect(self.paintbuttonevent)
        self.leave_btn.emit(0)


    #
    # 函数：鼠标进入事件
    #
    def enterEvent(self,event):
        self.enter_btn.emit(1)
        self.status = BUTTON_ENTER
        self.update()

    #
    # 函数：鼠标按下事件
    #
    def mousePressEvent(self,event):
        if(event.button() == Qt.LeftButton):
            self.mouse_press = True
            self.status = BUTTON_PRESSED
            self.update()

    #
    # 函数：鼠标释放事件
    #
    def mouseReleaseEvent(self,event):
        if(self.mouse_press and self.rect().contains(event.pos())):
            self.mouse_press = False
            self.click_btn.emit(2)
            self.status = BUTTON_ENTER
            self.update()
            self.clicked.emit(True)

    #
    # 函数：鼠标离开事件
    #
    def leaveEvent(self,event):
        self.leave_btn.emit(0)
        self.status = BUTTON_LEAVE
        self.update()

    #
    # 函数：绘图函数
    #
    def paintbuttonevent(self,mouse_state=0):
        self.painter = QPainter()
        if mouse_state==0:
            if self.isclosebtn:
                self.setStyleSheet("QPushButton{background-color:transparent;border-radius:4px;image: url(./res/close1.png);}")
            elif self.isminibtn:
                self.setStyleSheet("QPushButton{background-color:transparent;border-radius:4px;image: url(./res/mini1.png);}")
            else:
                self.setStyleSheet("QPushButton{background-color:transparent;border-radius:4px;image: url(./res/set1.png);}")
        elif mouse_state==1:
            if self.isclosebtn:
                self.setStyleSheet("QPushButton{background-color:#f86457;border-radius:4px;image: url(./res/close2.png);}")
            elif self.isminibtn:
                self.setStyleSheet("QPushButton{background-color:rgba(0, 0, 0, 0.04);border-radius:4px;image: url(./res/mini2.png);}")
            else:
                self.setStyleSheet("QPushButton{background-color:rgba(0, 0, 0, 0.04);border-radius:4px;image: url(./res/set2.png);}")
        elif mouse_state==2:
            if self.isclosebtn:
                self.setStyleSheet("QPushButton{background-color:#e44c50;border-radius:4px;image: url(./res/close3.png);}")
            elif self.isminibtn:
                self.setStyleSheet("QPushButton{background-color:rgba(48, 49, 51, 0.08);border-radius:4px;image: url(./res/mini3.png);}")
            else:
                self.setStyleSheet("QPushButton{background-color:rgba(48, 49, 51, 0.08);border-radius:4px;image: url(./res/set3.png);}")


class Click_Button(QPushButton):
    leave_btn = pyqtSignal(int)
    enter_btn = pyqtSignal(int)
    click_btn = pyqtSignal(int)
    clicked_this_btn = pyqtSignal(str)
    is_clicked = False

    def __init__(self, text,paint_parent,parent=None):
        super(Click_Button,self).__init__(parent)
        # self.setStyleSheet("QPushButton{border-radius:4px;background-color:#3d6be5;}")
        self.m_parent = parent
        self.mouse_press = False
        self.setFocusPolicy(Qt.NoFocus)
        self.status = BUTTON_LEAVE
        self.setText(text)
        self.adjustSize()
        self.setFixedHeight(24)
        self.click_btn.connect(self.paintbuttonevent)
        self.enter_btn.connect(self.paintbuttonevent)
        self.leave_btn.connect(self.paintbuttonevent)
        self.clicked_this_btn.connect(paint_parent.slot_clicked_btn)
        self.paint_parent = paint_parent
        if(text == _("ubuntukylin")):
            self.is_clicked = True
            self.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #ffffff;background-color:#12C188;text-align: center;border-radius:12px;}")
            self.clicked_this_btn.emit(self.text())
        elif(text == _("Onload")):
            self.is_clicked = True
            self.setStyleSheet("QPushButton{border-radius: 12px;font-size: 14px;font-weight: 400;line-height: 20px;text-align: center;background-color: #3790FA;color: #ffffff;}")
            self.clicked_this_btn.emit(self.text())
        else:
            self.setStyleSheet("QPushButton{background-color:transparent;border-radius: 12px;font-size: 14px;font-weight: 400;text-align: center;color: #606265;line-height: 20px;}QPushButton:hover{background: rgba(55, 144, 250, 0.12);color: #3790FA;}QPushButton:pressed{background-color: #3790FA;color: #ffffff;}")

    #
    # 函数：鼠标进入事件
    #
    def enterEvent(self, event):
        self.enter_btn.emit(1)
        self.status = BUTTON_ENTER
        self.update()

    #
    # 函数：鼠标按下事件
    #
    def mousePressEvent(self, event):
        if (event.button() == Qt.LeftButton):
            self.mouse_press = True
            self.status = BUTTON_PRESSED
            self.update()

    #
    # 函数：鼠标释放事件
    #
    def mouseReleaseEvent(self, event):
        if (self.mouse_press and self.rect().contains(event.pos())):
            self.mouse_press = False
            self.show_which_btn()
            self.status = BUTTON_ENTER
            self.update()

    #
    # 函数：鼠标离开事件
    #
    def leaveEvent(self, event):
        self.leave_btn.emit(0)
        self.status = BUTTON_LEAVE
        self.update()

    #
    #函数：判断该按钮是否显示点击状态
    #
    def show_which_btn(self):
        self.click_btn.emit(2)
        state = self.is_clicked
        self.is_clicked = False
        clicked = self.paint_parent.paint_btn()
        if (clicked == False):
            self.is_clicked = True
        else:
            self.is_clicked = state
            if (self.is_clicked == False):
                self.is_clicked = True
            else:
                self.is_clicked = False
        if (self.is_clicked == True):
            try:
                self.paint_parent.type_name_label.setText(self.text())
                self.paint_parent.type_name_label.adjustSize()
            except:
                pass
            self.clicked_this_btn.emit(self.text())


    #
    # 函数：绘图函数
    #
    def paintbuttonevent(self, mouse_state=0):
        self.painter = QPainter()
        if(Globals.THEME_COLOR == 0):
            if mouse_state == 0:
                if(self.is_clicked == False):
                    self.setStyleSheet("QPushButton{background-color:transparent;border-radius: 12px;font-size: 14px;text-align: center;font-weight: 400;color: #606265;line-height: 20px;}")
                else:
                    self.setStyleSheet("QPushButton{border-radius: 12px;font-size: 14px;font-weight: 400;text-align: center;line-height: 20px;background-color: #3790FA;color: #ffffff;}")
            elif mouse_state == 1:
                if (self.is_clicked == False):
                    self.setStyleSheet("QPushButton{border-radius: 12px;font-size: 14px;font-weight: 400;text-align: center;line-height: 20px;background: rgba(55, 144, 250, 0.12);color: #3790FA;}")
                else:
                    self.setStyleSheet("QPushButton{border-radius: 12px;font-size: 14px;font-weight: 400;text-align: center;line-height: 20px;background-color: #3790FA;color: #ffffff;}")
            elif mouse_state == 2:
                self.setStyleSheet("QPushButton{border-radius: 12px;font-size: 14px;font-weight: 400;text-align: center;line-height: 20px;background-color: #3790FA;color: #ffffff;}")
        else:
            if mouse_state == 0:
                if (self.is_clicked == False):
                    self.setStyleSheet(
                        "QPushButton{background-color:transparent;border-radius: 12px;font-size: 14px;text-align: center;font-weight: 400;color: #8F9399;line-height: 20px;}")
                else:
                    self.setStyleSheet(
                        "QPushButton{border-radius: 12px;font-size: 14px;font-weight: 400;text-align: center;line-height: 20px;background-color: #3790FA;color: #ffffff;}")
            elif mouse_state == 1:
                if (self.is_clicked == False):
                    self.setStyleSheet(
                        "QPushButton{border-radius: 12px;font-size: 14px;font-weight: 400;text-align: center;line-height: 20px;background: rgba(55, 144, 250, 0.12);color: #3790FA;}")
                else:
                    self.setStyleSheet(
                        "QPushButton{border-radius: 12px;font-size: 14px;font-weight: 400;text-align: center;line-height: 20px;background-color: #3790FA;color: #ffffff;}")
            elif mouse_state == 2:
                self.setStyleSheet(
                    "QPushButton{border-radius: 12px;font-size: 14px;font-weight: 400;text-align: center;line-height: 20px;background-color: #3790FA;color: #ffffff;}")


if __name__ == '__main__':
   import sys
   app = QApplication(sys.argv)
   btn = SystemButton()
   btn.loadPixmap("../res/close_button.png")
   btn.show()
   sys.exit(app.exec_())


import os
import math
from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
from ui.systembutton import *
from models.enums import CACHE_DIR,BUTTON_PRESSED,BUTTON_ENTER,BUTTON_LEAVE,BUTTON_DISABLE
import gettext
gettext.bindtextdomain("kylin-software-center", "/usr/share/locale")
gettext.textdomain("kylin-software-center")
_ = gettext.gettext

class Tip_Widget(QWidget):
    def __init__(self,text,parent = None):
        QWidget.__init__(self, parent)
        self.text = text
        self.mouse_press = False
        self.init_ui()
        self.paintEvent = self.set_paintEvent

    def init_ui(self):
        self.setFixedSize(442,182)
        self.setWindowFlags(Qt.FramelessWindowHint | Qt.Tool)
        self.setWindowTitle(_("Software Store"))
        self.setAttribute(Qt.WA_TranslucentBackground)
        self.widget = QWidget(self)
        self.widget.resize(424,164)
        self.widget.move(9,9)
        #self.widget.setStyleSheet("QWidget{background: rgba(255, 255, 255, 0.7);border-radius:12px;background-color:#ffffff;}")
        self.title_label = QLabel(self.widget)
        self.title_label.setFixedSize(170,16)
        self.title_label.setText(_("Tip"))
        self.title_label.setStyleSheet("QLabel{border:0px;font-size: 14px;color: #1B1B1B;font-weight: 500;line-height: 14px;}")
        self.title_label.move(16,12)

        self.warning_label = QLabel(self.widget)
        self.warning_label.resize(24,24)
        self.warning_label.setStyleSheet("QLabel{border:0px;background-image:url(./res/warning.png);background-color:transparent;}")
        self.warning_label.move(16,55)
        self.warning_label.hide()

        self.line_label = QLabel(self.widget)
        self.line_label.setFixedSize(422,1)
        self.line_label.setStyleSheet("QLabel{width: 424px;height: 1px;background: #F2F6FD;}")
        self.line_label.move(1,38)

        self.close_btn = QPushButton(self.widget)
        self.close_btn.setFocusPolicy(Qt.NoFocus)
        self.close_btn.resize(30,30)
        self.close_btn.setStyleSheet("QPushButton{border-radius: 4px;border:0px;border-image:url('res/close1.png')}QPushButton:hover{border:0px;border-image:url('res/close2.png')}QPushButton:pressed{border:0px;border-image:url('res/close3.png')}")
        self.close_btn.move(self.widget.width()-self.close_btn.width()-4,4)
        self.close_btn.setToolTip(_("close"))

        self.tips_label = QLabel(self.widget)
        self.tips_label.setWordWrap(True)
        self.tips_label.setAlignment(Qt.AlignLeft)
        self.tips_label.setFixedWidth(self.widget.width()-self.warning_label.width()-self.warning_label.x()-16)
        self.tips_label.setText(self.text)
        # self.tips_label.adjustSize()
        self.tips_label.move(int((self.widget.width()-self.tips_label.width())/2),55)

        self.btn = QPushButton(self.widget)
        self.btn.setFocusPolicy(Qt.NoFocus)
        self.btn.setFixedSize(64,30)
        self.btn.setStyleSheet("QPushButton{background: #3790FA;border-radius: 6px;font-size: 14px;font-weight: 400;color: #FFFFFF;text-align: center;line-height: 12px;}QPushButton:hover{background: #40A9FB;;border-radius: 6px;color: #ffffff;}QPushButton:pressed{background: #296CD9;border-radius: 6px;color: #ffffff;}")
        self.btn.setText(_("OK"))
        self.btn.move(int((self.widget.width()-self.btn.width())/2),110)

        self.cancel_btn = QPushButton(self.widget)
        self.cancel_btn.setFocusPolicy(Qt.NoFocus)
        self.cancel_btn.setFixedSize(64, 30)
        self.cancel_btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #8F9399;line-height: 20px;border-radius: 6px;text-align: center;border: 1px solid #DDDFE7;}QPushButton:hover{background: #F2F6FD;border-radius: 6px;border: 1px solid #DDDFE7;}QPushButton:pressed{background: #F2F6FD;border-radius: 6px;border: 1px solid #DDDFE7;}")
        self.cancel_btn.setText(_("cancel"))
        self.cancel_btn.move(172, 110)
        self.cancel_btn.hide()

        self.slot_show_dark_mode()

    #
    # 函数：处理主题颜色的显示
    #
    def slot_show_dark_mode(self):
        if (Globals.THEME_COLOR == 0):
            if(Globals.RIGHT_ANGLE):
                self.widget.setStyleSheet(".QWidget{background-color:#ffffff;border: 1px solid rgba(38, 38, 38, 0.15);}")
                self.setStyleSheet("QFrame{background-color:#ffffff;}")
            else:
                self.widget.setStyleSheet(".QWidget{border-radius:12px;background-color:#ffffff;border: 1px solid rgba(38, 38, 38, 0.15);}")
                self.setStyleSheet("QFrame{background-color:#ffffff;}")
            self.title_label.setStyleSheet("QLabel{font-size: 14px;color: #1B1B1B;font-weight: 500;background:transparent;}")
            self.tips_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 24px;background:transparent;}")
            self.line_label.setStyleSheet("QLabel{width: 424px;height: 1px;background: #F2F6FD;}")
            self.close_btn.setStyleSheet("QPushButton{border-radius: 4px;border:0px;border-image:url('res/close1.png')}QPushButton:hover{border:0px;border-image:url('res/close2.png')}QPushButton:pressed{border:0px;border-image:url('res/close3.png')}")
        else:
            if (Globals.RIGHT_ANGLE):
                self.widget.setStyleSheet(".QWidget{background-color:#3D3D41;border: 1px solid rgba(38, 38, 38, 0.15);}")
                self.setStyleSheet("QFrame{background-color:#1F2022;}")
            else:
                self.setStyleSheet("QFrame{background-color:#1F2022;}")
                self.widget.setStyleSheet(".QWidget{border-radius:12px;background-color:#3D3D41;border: 1px solid rgba(38, 38, 38, 0.15);}")
            self.title_label.setStyleSheet("QLabel{font-size: 14px;color: #8F9399;line-height: 14px;font-weight: 500;background:transparent;}")
            self.tips_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #C0C4CC;line-height: 24px;background:transparent;}")
            self.line_label.setStyleSheet("QLabel{width: 424px;height: 1px;background: #48484C;}")
            self.close_btn.setStyleSheet(
                "QPushButton{border-radius: 4px;border:0px;border-image:url('res/common-close-white.png')}QPushButton:hover{border:0px;border-image:url('res/hover-close.png')}QPushButton:pressed{border:0px;border-image:url('res/clicked-close.png')}")
        # QApplication.processEvents()

    #
    # 函数：重绘函数
    #
    def set_paintEvent(self, event):
        painter = QPainter(self)
        m_defaultBackgroundColor = QColor(qRgba(0, 0, 0, 16))
        m_defaultBackgroundColor.setAlpha(50)
        path = QPainterPath()
        path.setFillRule(Qt.WindingFill)
        path.addRoundedRect(10, 10, self.width() - 20, self.height() - 20, 12, 12)

        painter.setRenderHint(QPainter.Antialiasing, True)
        painter.fillPath(path, QBrush(QColor(m_defaultBackgroundColor.red(),
                                             m_defaultBackgroundColor.green(),
                                             m_defaultBackgroundColor.blue())))

        color = QColor(0, 0, 0, 16)
        i = 0
        while i < 4:
            path = QPainterPath()
            path.setFillRule(Qt.WindingFill)
            path.addRoundedRect(10 - i, 10 - i, self.width() - (10 - i) * 2, self.height() - (10 - i) * 2, 12, 12)
            color.setAlpha(int(100 - math.sqrt(i) * 50))
            painter.setPen(color)
            painter.drawPath(path)
            i = i + 1

        painter.setRenderHint(QPainter.Antialiasing)

    #
    # 函数：实现无标题栏窗口拖动
    #
    def mousePressEvent(self, event):
        if (event.button() == Qt.LeftButton):
            self.mouse_press = True
            self.drag_pos = event.globalPos() - self.pos()
            event.accept()

    def mouseReleaseEvent(self, event):
        self.mouse_press = False
        self.setWindowOpacity(1)

    # def mouseMoveEvent(self, event):
    #     if (self.mouse_press):
    #         self.move_pos = event.globalPos()
    #         self.move(self.move_pos - self.drag_pos)
    #         self.setWindowOpacity(1)
    #         event.accept()

class Click_All_Search(QFrame):

    def __init__(self, mw,parent=None):
        QFrame.__init__(self, parent)
        self.mw = mw
        self.label1 = QLabel(self)
        self.label1.setAlignment(Qt.AlignHCenter)
        self.label1.setAttribute(Qt.WA_TranslucentBackground)
        if (Globals.THEME_COLOR == 0):
            self.label1.setStyleSheet("QLabel{font-size: 20px;font-weight: 400;color: #303133;line-height: 24px;}")
        else:
            self.label1.setStyleSheet("QLabel{font-size: 20px;font-weight: 400;color: #F9F9F9;line-height: 24px;}")
        self.label1.setText(_("Go to"))
        self.label1.adjustSize()
        self.label1.move(0, 0)
        self.all_btn = QPushButton(self)
        self.all_btn.resize(self.mw.detailwidget.no_found_text2.width() + 20, self.mw.detailwidget.no_found_text2.height())
        self.all_btn.setFocusPolicy(Qt.NoFocus)
        self.all_btn.setAttribute(Qt.WA_TranslucentBackground)
        self.all_btn.setStyleSheet(
            "QPushButton{font-size: 20px;border:0px;font-weight: 400;line-height: 24px;background-color:transparent;color:#3790FA;}QPushButton:hover{background:transparent;}QPushButton:pressed{background:transparent;}")
        self.all_btn.move(self.label1.x() + self.label1.width()+3, self.label1.y())
        locale_lan = QLocale.system().name()
        if (locale_lan == "zh_CN"):
            self.all_btn.resize(70, self.label1.height())
        self.all_btn.setText(_("full library"))
        self.all_btn.adjustSize()
        self.all_btn.clicked.connect(self.mw.detailwidget.slot_cilck_all_search_btn)
        self.label2 = QLabel(self)
        self.label2.setAlignment(Qt.AlignHCenter)
        self.label2.setAttribute(Qt.WA_TranslucentBackground)
        if (Globals.THEME_COLOR == 0):
            self.label2.setStyleSheet("QLabel{font-size: 20px;font-weight: 400;color: #303133;line-height: 24px;}")
        else:
            self.label2.setStyleSheet("QLabel{font-size: 20px;font-weight: 400;color: #F9F9F9;line-height: 24px;}")
        self.label2.setText(_("to search!"))
        self.label2.adjustSize()
        self.label2.move(self.all_btn.x() + self.all_btn.width()+3, self.all_btn.y())

    def change_color(self):
        if (Globals.THEME_COLOR == 0):
            self.label1.setStyleSheet("QLabel{font-size: 20px;font-weight: 400;color: #303133;line-height: 24px;}")
            self.label2.setStyleSheet("QLabel{font-size: 20px;font-weight: 400;color: #303133;line-height: 24px;}")
        else:
            self.label1.setStyleSheet("QLabel{font-size: 20px;font-weight: 400;color: #F9F9F9;line-height: 24px;}")
            self.label2.setStyleSheet("QLabel{font-size: 20px;font-weight: 400;color: #F9F9F9;line-height: 24px;}")

